@@ -58,4 +58,8 @@ class AgentJinjaTemplater(object):
              'respawn_count': CONF.haproxy_amphora.respawn_count,
              'respawn_interval': CONF.haproxy_amphora.respawn_interval,
              'amphora_udp_driver': CONF.amphora_agent.amphora_udp_driver,
-             'topology': topology})
+             'agent_tls_protocol': CONF.amphora_agent.agent_tls_protocol,
+             'topology': topology,
+             'administrative_log_facility':
+                 CONF.amphora_agent.administrative_log_facility,
+             'user_log_facility': CONF.amphora_agent.user_log_facility})
