@@ -18,6 +18,7 @@ import subprocess
 
 import flask
 import jinja2
+from oslo_config import cfg
 from oslo_log import log as logging
 import webob
 
@@ -27,6 +28,7 @@ from octavia.common import constants as consts
 
 
 BUFFER = 100
+CONF = cfg.CONF
 
 LOG = logging.getLogger(__name__)
 
@@ -45,6 +47,7 @@ class Keepalived(object):
 
         if not os.path.exists(util.keepalived_dir()):
             os.makedirs(util.keepalived_dir())
+        if not os.path.exists(util.keepalived_check_scripts_dir()):
             os.makedirs(util.keepalived_check_scripts_dir())
 
         conf_file = util.keepalived_cfg_path()
@@ -92,7 +95,9 @@ class Keepalived(object):
                     keepalived_cfg=util.keepalived_cfg_path(),
                     keepalived_log=util.keepalived_log_path(),
                     amphora_nsname=consts.AMPHORA_NAMESPACE,
-                    amphora_netns=consts.AMP_NETNS_SVC_PREFIX
+                    amphora_netns=consts.AMP_NETNS_SVC_PREFIX,
+                    administrative_log_facility=(
+                        CONF.amphora_agent.administrative_log_facility),
                 )
                 text_file.write(text)
 
@@ -108,6 +113,9 @@ class Keepalived(object):
                 )
                 text_file.write(text)
 
+        # Configure the monitoring of haproxy
+        util.vrrp_check_script_update(None, consts.AMP_ACTION_START)
+
         # Make sure the new service is enabled on boot
         if init_system != consts.INIT_UPSTART:
             try:
