@@ -147,7 +147,7 @@ class KeepalivedLvs(udp_listener_base.UdpListenerApiServerBase):
             except subprocess.CalledProcessError as e:
                 LOG.debug('Failed to enable '
                           'octavia-keepalivedlvs service: '
-                          '%(err)s', {'err': e})
+                          '%(err)s', {'err': str(e)})
                 return webob.Response(json=dict(
                     message="Error enabling "
                             "octavia-keepalivedlvs service",
@@ -169,6 +169,7 @@ class KeepalivedLvs(udp_listener_base.UdpListenerApiServerBase):
                         keepalived_lvs_pid_dir=util.keepalived_lvs_dir()
                     )
                     script_file.write(text)
+            util.vrrp_check_script_update(None, consts.AMP_ACTION_START)
 
         res = webob.Response(json={'message': 'OK'}, status=200)
         res.headers['ETag'] = stream.get_md5()
@@ -222,7 +223,7 @@ class KeepalivedLvs(udp_listener_base.UdpListenerApiServerBase):
             subprocess.check_output(cmd.split(), stderr=subprocess.STDOUT)
         except subprocess.CalledProcessError as e:
             LOG.debug('Failed to %s keepalivedlvs listener %s',
-                      listener_id + ' : ' + action, e)
+                      listener_id + ' : ' + action, str(e))
             return webob.Response(json=dict(
                 message=("Failed to {0} keepalivedlvs listener {1}"
                          .format(action, listener_id)),
@@ -283,7 +284,7 @@ class KeepalivedLvs(udp_listener_base.UdpListenerApiServerBase):
             try:
                 subprocess.check_output(cmd.split(), stderr=subprocess.STDOUT)
             except subprocess.CalledProcessError as e:
-                LOG.error("Failed to stop keepalivedlvs service: %s", e)
+                LOG.error("Failed to stop keepalivedlvs service: %s", str(e))
                 return webob.Response(json=dict(
                     message="Error stopping keepalivedlvs",
                     details=e.output), status=500)
@@ -316,7 +317,7 @@ class KeepalivedLvs(udp_listener_base.UdpListenerApiServerBase):
             except subprocess.CalledProcessError as e:
                 LOG.error("Failed to disable "
                           "octavia-keepalivedlvs-%(list)s service: "
-                          "%(err)s", {'list': listener_id, 'err': e})
+                          "%(err)s", {'list': listener_id, 'err': str(e)})
                 return webob.Response(json=dict(
                     message=(
                         "Error disabling octavia-keepalivedlvs-"
