@@ -23,7 +23,6 @@ import distro
 import jinja2
 from oslo_config import cfg
 from oslo_log import log as logging
-import six
 import webob
 from werkzeug import exceptions
 
@@ -41,10 +40,9 @@ j2_env = jinja2.Environment(autoescape=True, loader=jinja2.FileSystemLoader(
 
 class BaseOS(object):
 
-    PACKAGE_NAME_MAP = {}
-
     def __init__(self, os_name):
         self.os_name = os_name
+        self.package_name_map = {}
 
     @classmethod
     def _get_subclasses(cls):
@@ -61,9 +59,8 @@ class BaseOS(object):
                 return subclass(os_name)
         raise octavia_exceptions.InvalidAmphoraOperatingSystem(os_name=os_name)
 
-    @classmethod
-    def _map_package_name(cls, package_name):
-        return cls.PACKAGE_NAME_MAP.get(package_name, package_name)
+    def _map_package_name(self, package_name):
+        return self.package_name_map.get(package_name, package_name)
 
     def get_network_interface_file(self, interface):
         if CONF.amphora_agent.agent_server_network_file:
@@ -164,11 +161,8 @@ class BaseOS(object):
                 try:
                     ip_addr = fixed_ip['ip_address']
                     cidr = fixed_ip['subnet_cidr']
-                    ip = ipaddress.ip_address(ip_addr if isinstance(
-                        ip_addr, six.text_type) else six.u(ip_addr))
-                    network = ipaddress.ip_network(
-                        cidr if isinstance(
-                            cidr, six.text_type) else six.u(cidr))
+                    ip = ipaddress.ip_address(ip_addr)
+                    network = ipaddress.ip_network(cidr)
                     broadcast = network.broadcast_address.exploded
                     netmask = (network.prefixlen if ip.version == 6
                                else network.netmask.exploded)
@@ -191,10 +185,7 @@ class BaseOS(object):
     def get_host_routes(cls, fixed_ip):
         host_routes = []
         for hr in fixed_ip.get('host_routes', []):
-            network = ipaddress.ip_network(
-                hr['destination'] if isinstance(
-                    hr['destination'], six.text_type) else
-                six.u(hr['destination']))
+            network = ipaddress.ip_network(hr['destination'])
             host_routes.append({'network': network, 'gw': hr['nexthop']})
         return host_routes
 
@@ -399,7 +390,7 @@ class RH(BaseOS):
         if not network_dir:
             network_dir = self.get_network_path()
         if not ignore:
-            ignore = shutil.ignore_patterns('ifcfg-eth0*', 'ifcfg-lo*')
+            ignore = shutil.ignore_patterns('ifcfg-eth0*')
         super(RH, self).create_netns_dir(
             network_dir, netns_network_dir, ignore)
 
@@ -504,8 +495,7 @@ class RH(BaseOS):
             host_routes_ipv6 = []
             for fixed_ip in fixed_ips:
                 ip_addr = fixed_ip['ip_address']
-                ip = ipaddress.ip_address(ip_addr if isinstance(
-                    ip_addr, six.text_type) else six.u(ip_addr))
+                ip = ipaddress.ip_address(ip_addr)
                 if ip.version == 6:
                     host_routes_ipv6.extend(self.get_host_routes(fixed_ip))
                 else:
@@ -582,7 +572,10 @@ class RH(BaseOS):
 
 class CentOS(RH):
 
-    PACKAGE_NAME_MAP = {'haproxy': 'haproxy18'}
+    def __init__(self, os_name):
+        super(CentOS, self).__init__(os_name)
+        if distro.version() == '7':
+            self.package_name_map.update({'haproxy': 'haproxy18'})
 
     @classmethod
     def is_os_name(cls, os_name):
