@@ -12,7 +12,7 @@
 # License for the specific language governing permissions and limitations
 #    under the License.
 
-import errno
+
 import os
 import re
 import stat
@@ -32,7 +32,7 @@ LOG = logging.getLogger(__name__)
 
 FRONTEND_BACKEND_PATTERN = re.compile(r'\n(frontend|backend)\s+(\S+)\n')
 LISTENER_MODE_PATTERN = re.compile(r'^\s+mode\s+(.*)$', re.MULTILINE)
-TLS_CERT_PATTERN = re.compile(r'^\s+bind\s+\S+\s+ssl crt-list\s+(.*)$',
+TLS_CERT_PATTERN = re.compile(r'^\s+bind\s+\S+\s+ssl crt-list\s+(\S*)',
                               re.MULTILINE)
 STATS_SOCKET_PATTERN = re.compile(r'stats socket\s+(\S+)')
 
@@ -337,12 +337,8 @@ def parse_haproxy_file(lb_id):
 
 
 def vrrp_check_script_update(lb_id, action):
-    try:
-        os.makedirs(keepalived_dir())
-        os.makedirs(keepalived_check_scripts_dir())
-    except OSError as e:
-        if e.errno != errno.EEXIST:
-            raise
+    os.makedirs(keepalived_dir(), exist_ok=True)
+    os.makedirs(keepalived_check_scripts_dir(), exist_ok=True)
 
     lb_ids = get_loadbalancers()
     udp_ids = get_udp_listeners()
