@@ -15,8 +15,12 @@
 
 from webob import exc
 
+from oslo_log import log as logging
 
-def check_exception(response):
+LOG = logging.getLogger(__name__)
+
+
+def check_exception(response, ignore=tuple(), log_error=True):
     status_code = response.status_code
     responses = {
         400: InvalidRequest,
@@ -28,7 +32,15 @@ def check_exception(response):
         500: InternalServerError,
         503: ServiceUnavailable
     }
-    if status_code in responses:
+    if (status_code not in ignore) and (status_code in responses):
+        try:
+            if log_error:
+                LOG.error('Amphora agent returned unexpected result code %s '
+                          'with response %s', status_code, response.json())
+        except Exception:
+            # Handle the odd case where there is no response body
+            # like when using requests_mock which doesn't support has_body
+            pass
         raise responses[status_code]()
 
     return response
