@@ -203,9 +203,9 @@ class HaproxyAmphoraLoadBalancerDriver(
                     else:
                         listeners_to_update.append(listener)
                 except Exception as e:
-                    LOG.error('Unable to update listener {0} due to "{1}". '
-                              'Skipping this listener.'.format(
-                                  listener.id, str(e)))
+                    LOG.exception('Unable to update listener %s due to '
+                                  '"%s". Skipping this listener.',
+                                  listener.id, str(e))
                     listener_repo = repo.ListenerRepository()
                     listener_repo.update(db_apis.get_session(), listener.id,
                                          provisioning_status=consts.ERROR,
@@ -505,8 +505,7 @@ class HaproxyAmphoraLoadBalancerDriver(
                 amphora, obj_id, pem=secret, md5=md5, name=name)
         return name
 
-    def _process_listener_pool_certs(self, listener, amphora=None,
-                                     obj_id=None):
+    def _process_listener_pool_certs(self, listener, amphora, obj_id):
         #     {'POOL-ID': {
         #         'client_cert': client_full_filename,
         #         'ca_cert': ca_cert_full_filename,
@@ -524,33 +523,34 @@ class HaproxyAmphoraLoadBalancerDriver(
                                              amphora, obj_id))
         return pool_certs_dict
 
-    def _process_pool_certs(self, listener, pool, amphora=None, obj_id=None):
+    def _process_pool_certs(self, listener, pool, amphora, obj_id):
         pool_cert_dict = dict()
 
         # Handle the client cert(s) and key
         if pool.tls_certificate_id:
             data = cert_parser.load_certificates_data(self.cert_manager, pool)
-            pem = cert_parser.build_pem(data)
+            tls_cert = data['tls_cert']
+            pem = cert_parser.build_pem(tls_cert)
             try:
                 pem = pem.encode('utf-8')
             except AttributeError:
                 pass
             md5 = hashlib.md5(pem).hexdigest()  # nosec
-            name = '{id}.pem'.format(id=data.id)
+            name = '{id}.pem'.format(id=tls_cert.id)
             if amphora and obj_id:
                 self._upload_cert(amphora, obj_id, pem=pem, md5=md5, name=name)
             pool_cert_dict['client_cert'] = os.path.join(
-                CONF.haproxy_amphora.base_cert_dir, listener.id, name)
+                CONF.haproxy_amphora.base_cert_dir, obj_id, name)
         if pool.ca_tls_certificate_id:
             name = self._process_secret(listener, pool.ca_tls_certificate_id,
                                         amphora, obj_id)
             pool_cert_dict['ca_cert'] = os.path.join(
-                CONF.haproxy_amphora.base_cert_dir, listener.id, name)
+                CONF.haproxy_amphora.base_cert_dir, obj_id, name)
         if pool.crl_container_id:
             name = self._process_secret(listener, pool.crl_container_id,
                                         amphora, obj_id)
             pool_cert_dict['crl'] = os.path.join(
-                CONF.haproxy_amphora.base_cert_dir, listener.id, name)
+                CONF.haproxy_amphora.base_cert_dir, obj_id, name)
 
         return pool_cert_dict
 
@@ -587,8 +587,8 @@ class HaproxyAmphoraLoadBalancerDriver(
             self.clients[amphora.api_version].update_agent_config(
                 amphora, agent_config, timeout_dict=timeout_dict)
         except exc.NotFound:
-            LOG.debug('Amphora {} does not support the update_agent_config '
-                      'API.'.format(amphora.id))
+            LOG.debug('Amphora %s does not support the update_agent_config '
+                      'API.', amphora.id)
             raise driver_except.AmpDriverNotImplementedError()
 
     def get_interface_from_ip(self, amphora, ip_address, timeout_dict=None):
