@@ -358,7 +358,7 @@ class PaginationHelper(object):
                         default = PaginationHelper._get_default_column_value(
                             model_attr.property.columns[0].type)
                         attr = sa_sql.expression.case(
-                            [(model_attr != None,  # noqa: E711 # pylint: disable=singleton-comparison
+                            [(model_attr.isnot(None),
                               model_attr), ], else_=default)
                         crit_attrs.append((attr == marker_values[j]))
 
@@ -366,7 +366,7 @@ class PaginationHelper(object):
                     default = PaginationHelper._get_default_column_value(
                         model_attr.property.columns[0].type)
                     attr = sa_sql.expression.case(
-                        [(model_attr != None,  # noqa: E711 # pylint: disable=singleton-comparison
+                        [(model_attr.isnot(None),
                           model_attr), ], else_=default)
                     this_sort_dir = self.sort_keys[i][1]
                     if this_sort_dir == constants.DESC:
