@@ -14,19 +14,16 @@
 
 import copy
 
+from dateutil import parser
 import netaddr
-import six
 from wsme import types as wtypes
 
 from octavia.common import exceptions
 from octavia.common import validate
 
-if six.PY3:
-    unicode = str
-
 
 class IPAddressType(wtypes.UserType):
-    basetype = unicode
+    basetype = str
     name = 'ipaddress'
 
     @staticmethod
@@ -45,7 +42,7 @@ class IPAddressType(wtypes.UserType):
 
 
 class CidrType(wtypes.UserType):
-    basetype = unicode
+    basetype = str
     name = 'cidr'
 
     @staticmethod
@@ -59,7 +56,7 @@ class CidrType(wtypes.UserType):
 
 
 class URLType(wtypes.UserType):
-    basetype = unicode
+    basetype = str
     name = 'url'
 
     def __init__(self, require_scheme=True):
@@ -76,7 +73,7 @@ class URLType(wtypes.UserType):
 
 
 class URLPathType(wtypes.UserType):
-    basetype = unicode
+    basetype = str
     name = 'url_path'
 
     @staticmethod
@@ -119,8 +116,7 @@ class BaseMeta(wtypes.BaseMeta):
         return super(BaseMeta, cls).__new__(cls, name, bases, dct)
 
 
-@six.add_metaclass(BaseMeta)
-class BaseType(wtypes.Base):
+class BaseType(wtypes.Base, metaclass=BaseMeta):
     @classmethod
     def _full_response(cls):
         return False
@@ -132,12 +128,19 @@ class BaseType(wtypes.Base):
         :param data_model: data model to convert from
         :param children: convert child data models
         """
+        type_dict = data_model.to_dict()
+        # We need to have json convertible data for storing it in persistence
+        # jobboard backend.
+        for k, v in type_dict.items():
+            if ('_at' in k or 'expiration' in k) and v is not None:
+                type_dict[k] = parser.parse(v)
+
         if not hasattr(cls, '_type_to_model_map'):
-            return cls(**data_model.to_dict())
+            return cls(**type_dict)
 
         dm_to_type_map = {value: key
                           for key, value in cls._type_to_model_map.items()}
-        type_dict = data_model.to_dict()
+
         new_dict = copy.deepcopy(type_dict)
         for key, value in type_dict.items():
             if isinstance(value, dict):
