@@ -12,25 +12,41 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from oslo_config import cfg
 from oslo_log import log as logging
+from oslo_middleware import healthcheck
+from pecan import abort as pecan_abort
+from pecan import expose as pecan_expose
 from pecan import request as pecan_request
-from pecan import rest
 from wsme import types as wtypes
 from wsmeext import pecan as wsme_pecan
 
 from octavia.api.v2 import controllers as v2_controller
 
-
+CONF = cfg.CONF
 LOG = logging.getLogger(__name__)
 
 
-class RootController(rest.RestController):
+class RootController(object):
     """The controller with which the pecan wsgi app should be created."""
 
     def __init__(self):
         super(RootController, self).__init__()
         setattr(self, 'v2.0', v2_controller.V2Controller())
         setattr(self, 'v2', v2_controller.V2Controller())
+        if CONF.api_settings.healthcheck_enabled:
+            self.healthcheck_obj = healthcheck.Healthcheck.app_factory(None)
+
+    # Run the oslo middleware healthcheck for /healthcheck
+    @pecan_expose('json')
+    @pecan_expose(content_type='plain/text')
+    @pecan_expose(content_type='text/html')
+    def healthcheck(self):  # pylint: disable=inconsistent-return-statements
+        if CONF.api_settings.healthcheck_enabled:
+            if pecan_request.method not in ['GET', 'HEAD']:
+                pecan_abort(405)
+            return self.healthcheck_obj.process_request(pecan_request)
+        pecan_abort(404)
 
     def _add_a_version(self, versions, version, url_version, status,
                        timestamp, base_url):
@@ -45,7 +61,7 @@ class RootController(rest.RestController):
         })
 
     @wsme_pecan.wsexpose(wtypes.text)
-    def get(self):
+    def index(self):
         host_url = pecan_request.path_url
 
         if not host_url.endswith('/'):
@@ -88,6 +104,15 @@ class RootController(rest.RestController):
         self._add_a_version(versions, 'v2.12', 'v2', 'SUPPORTED',
                             '2019-09-11T00:00:00Z', host_url)
         # SOURCE_IP_PORT algorithm
-        self._add_a_version(versions, 'v2.13', 'v2', 'CURRENT',
+        self._add_a_version(versions, 'v2.13', 'v2', 'SUPPORTED',
                             '2019-09-13T00:00:00Z', host_url)
+        # Availability Zones
+        self._add_a_version(versions, 'v2.14', 'v2', 'SUPPORTED',
+                            '2019-11-10T00:00:00Z', host_url)
+        # TLS version and cipher options
+        self._add_a_version(versions, 'v2.15', 'v2', 'SUPPORTED',
+                            '2020-03-10T00:00:00Z', host_url)
+        # Additional UDP Healthcheck Types (HTTP/TCP)
+        self._add_a_version(versions, 'v2.16', 'v2', 'CURRENT',
+                            '2020-03-15T00:00:00Z', host_url)
         return {'versions': versions}
