@@ -18,7 +18,7 @@ from oslo_log import log as logging
 from oslo_serialization import jsonutils
 from oslo_utils import excutils
 from oslo_utils import uuidutils
-import pecan
+from pecan import request as pecan_request
 from sqlalchemy.orm import exc as sa_exception
 from wsme import types as wtypes
 from wsmeext import pecan as wsme_pecan
@@ -44,9 +44,12 @@ class FlavorProfileController(base.BaseController):
                          [wtypes.text], ignore_extra_args=True)
     def get_one(self, id, fields=None):
         """Gets a flavor profile's detail."""
-        context = pecan.request.context.get('octavia_context')
+        context = pecan_request.context.get('octavia_context')
         self._auth_validate_action(context, context.project_id,
                                    constants.RBAC_GET_ONE)
+        if id == constants.NIL_UUID:
+            raise exceptions.NotFound(resource='Flavor profile',
+                                      id=constants.NIL_UUID)
         db_flavor_profile = self._get_db_flavor_profile(context.session, id)
         result = self._convert_db_to_type(db_flavor_profile,
                                           profile_types.FlavorProfileResponse)
@@ -58,7 +61,7 @@ class FlavorProfileController(base.BaseController):
                          [wtypes.text], ignore_extra_args=True)
     def get_all(self, fields=None):
         """Lists all flavor profiles."""
-        pcontext = pecan.request.context
+        pcontext = pecan_request.context
         context = pcontext.get('octavia_context')
         self._auth_validate_action(context, context.project_id,
                                    constants.RBAC_GET_ALL)
@@ -78,7 +81,7 @@ class FlavorProfileController(base.BaseController):
     def post(self, flavor_profile_):
         """Creates a flavor Profile."""
         flavorprofile = flavor_profile_.flavorprofile
-        context = pecan.request.context.get('octavia_context')
+        context = pecan_request.context.get('octavia_context')
         self._auth_validate_action(context, context.project_id,
                                    constants.RBAC_POST)
         # Do a basic JSON validation on the metadata
@@ -135,11 +138,14 @@ class FlavorProfileController(base.BaseController):
     def put(self, id, flavor_profile_):
         """Updates a flavor Profile."""
         flavorprofile = flavor_profile_.flavorprofile
-        context = pecan.request.context.get('octavia_context')
+        context = pecan_request.context.get('octavia_context')
         self._auth_validate_action(context, context.project_id,
                                    constants.RBAC_PUT)
 
         self._validate_update_fp(context, id, flavorprofile)
+        if id == constants.NIL_UUID:
+            raise exceptions.NotFound(resource='Flavor profile',
+                                      id=constants.NIL_UUID)
 
         if not isinstance(flavorprofile.flavor_data, wtypes.UnsetType):
             # Do a basic JSON validation on the metadata
@@ -184,17 +190,20 @@ class FlavorProfileController(base.BaseController):
     @wsme_pecan.wsexpose(None, wtypes.text, status_code=204)
     def delete(self, flavor_profile_id):
         """Deletes a Flavor Profile"""
-        context = pecan.request.context.get('octavia_context')
+        context = pecan_request.context.get('octavia_context')
 
         self._auth_validate_action(context, context.project_id,
                                    constants.RBAC_DELETE)
 
+        if flavor_profile_id == constants.NIL_UUID:
+            raise exceptions.NotFound(resource='Flavor profile',
+                                      id=constants.NIL_UUID)
+
         # Don't allow it to be deleted if it is in use by a flavor
         if self.repositories.flavor.count(
                 context.session, flavor_profile_id=flavor_profile_id) > 0:
             raise exceptions.ObjectInUse(object='Flavor profile',
                                          id=flavor_profile_id)
-
         try:
             self.repositories.flavor_profile.delete(context.session,
                                                     id=flavor_profile_id)
