@@ -13,11 +13,12 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from oslo_db import api as oslo_db_api
 from oslo_db import exception as odb_exceptions
 from oslo_log import log as logging
 from oslo_utils import excutils
 from oslo_utils import uuidutils
-import pecan
+from pecan import request as pecan_request
 from sqlalchemy.orm import exc as sa_exception
 from wsme import types as wtypes
 from wsmeext import pecan as wsme_pecan
@@ -41,10 +42,11 @@ class FlavorsController(base.BaseController):
                          [wtypes.text], ignore_extra_args=True)
     def get_one(self, id, fields=None):
         """Gets a flavor's detail."""
-        context = pecan.request.context.get('octavia_context')
+        context = pecan_request.context.get('octavia_context')
         self._auth_validate_action(context, context.project_id,
                                    constants.RBAC_GET_ONE)
-
+        if id == constants.NIL_UUID:
+            raise exceptions.NotFound(resource='Flavor', id=constants.NIL_UUID)
         db_flavor = self._get_db_flavor(context.session, id)
         result = self._convert_db_to_type(db_flavor,
                                           flavor_types.FlavorResponse)
@@ -56,7 +58,7 @@ class FlavorsController(base.BaseController):
                          [wtypes.text], ignore_extra_args=True)
     def get_all(self, fields=None):
         """Lists all flavors."""
-        pcontext = pecan.request.context
+        pcontext = pecan_request.context
         context = pcontext.get('octavia_context')
         self._auth_validate_action(context, context.project_id,
                                    constants.RBAC_GET_ALL)
@@ -75,7 +77,7 @@ class FlavorsController(base.BaseController):
     def post(self, flavor_):
         """Creates a flavor."""
         flavor = flavor_.flavor
-        context = pecan.request.context.get('octavia_context')
+        context = pecan_request.context.get('octavia_context')
         self._auth_validate_action(context, context.project_id,
                                    constants.RBAC_POST)
 
@@ -104,9 +106,11 @@ class FlavorsController(base.BaseController):
                          body=flavor_types.FlavorRootPUT)
     def put(self, id, flavor_):
         flavor = flavor_.flavor
-        context = pecan.request.context.get('octavia_context')
+        context = pecan_request.context.get('octavia_context')
         self._auth_validate_action(context, context.project_id,
                                    constants.RBAC_PUT)
+        if id == constants.NIL_UUID:
+            raise exceptions.NotFound(resource='Flavor', id=constants.NIL_UUID)
         lock_session = db_api.get_session(autocommit=False)
         try:
             flavor_dict = flavor.to_dict(render_unsets=False)
@@ -126,17 +130,32 @@ class FlavorsController(base.BaseController):
                                           flavor_types.FlavorResponse)
         return flavor_types.FlavorRootResponse(flavor=result)
 
+    @oslo_db_api.wrap_db_retry(max_retries=5, retry_on_deadlock=True)
     @wsme_pecan.wsexpose(None, wtypes.text, status_code=204)
     def delete(self, flavor_id):
         """Deletes a Flavor"""
-        context = pecan.request.context.get('octavia_context')
+        context = pecan_request.context.get('octavia_context')
 
         self._auth_validate_action(context, context.project_id,
                                    constants.RBAC_DELETE)
+        if flavor_id == constants.NIL_UUID:
+            raise exceptions.NotFound(resource='Flavor', id=constants.NIL_UUID)
+        serial_session = db_api.get_session(autocommit=False)
+        serial_session.connection(
+            execution_options={'isolation_level': 'SERIALIZABLE'})
         try:
-            self.repositories.flavor.delete(context.session, id=flavor_id)
+            self.repositories.flavor.delete(serial_session, id=flavor_id)
+            serial_session.commit()
         # Handle when load balancers still reference this flavor
         except odb_exceptions.DBReferenceError:
+            serial_session.rollback()
             raise exceptions.ObjectInUse(object='Flavor', id=flavor_id)
         except sa_exception.NoResultFound:
+            serial_session.rollback()
             raise exceptions.NotFound(resource='Flavor', id=flavor_id)
+        except Exception as e:
+            with excutils.save_and_reraise_exception():
+                LOG.error('Unknown flavor delete exception: %s', str(e))
+                serial_session.rollback()
+        finally:
+            serial_session.close()
