@@ -40,10 +40,8 @@ class AmphoraAgent(gunicorn.app.base.BaseApplication):
         super(AmphoraAgent, self).__init__()
 
     def load_config(self):
-        config = dict(
-            [(key, value) for key, value in self.options.items()
-             if key in self.cfg.settings and value is not None]
-        )
+        config = {key: value for key, value in self.options.items()
+                  if key in self.cfg.settings and value is not None}
         for key, value in config.items():
             self.cfg.set(key.lower(), value)
 
@@ -69,6 +67,7 @@ def main():
 
     bind_ip_port = utils.ip_port_str(CONF.haproxy_amphora.bind_host,
                                      CONF.haproxy_amphora.bind_port)
+    proto = CONF.amphora_agent.agent_tls_protocol.replace('.', '_')
     options = {
         'bind': bind_ip_port,
         'workers': 1,
@@ -76,9 +75,15 @@ def main():
         'certfile': CONF.amphora_agent.agent_server_cert,
         'ca_certs': CONF.amphora_agent.agent_server_ca,
         'cert_reqs': ssl.CERT_REQUIRED,
+        'ssl_version': getattr(ssl, "PROTOCOL_%s" % proto),
         'preload_app': True,
         'accesslog': '/var/log/amphora-agent.log',
         'errorlog': '/var/log/amphora-agent.log',
         'loglevel': 'debug',
+        'syslog': True,
+        'syslog_facility': 'local{}'.format(
+            CONF.amphora_agent.administrative_log_facility),
+        'syslog_addr': 'unix://run/rsyslog/octavia/log#dgram',
+
     }
     AmphoraAgent(server_instance.app, options).run()
