@@ -104,6 +104,9 @@ api_opts = [
     cfg.BoolOpt('healthcheck_enabled', default=False,
                 help=_("When True, the oslo middleware healthcheck endpoint "
                        "is enabled in the Octavia API.")),
+    cfg.IntOpt('healthcheck_refresh_interval', default=5,
+               help=_("The interval healthcheck plugins should cache results, "
+                      "in seconds.")),
     cfg.StrOpt('default_listener_ciphers',
                default=constants.CIPHERS_OWASP_SUITE_B,
                help=_("Default OpenSSL cipher string (colon-separated) for "
@@ -581,7 +584,8 @@ certificate_opts = [
                default='publicURL',
                help='The endpoint_type to be used for barbican service.'),
     cfg.StrOpt('ca_certificates_file',
-               help=_('CA certificates file path')),
+               help=_('CA certificates file path for the key manager service '
+                      '(such as Barbican).')),
     cfg.BoolOpt('insecure',
                 default=False,
                 help=_('Disable certificate validation on SSL connections ')),
