@@ -16,7 +16,6 @@ import os
 import re
 
 import jinja2
-import six
 
 from octavia.common.config import cfg
 from octavia.common import constants
@@ -284,6 +283,10 @@ class JinjaTemplater(object):
                     os.path.join(self.base_crt_dir, loadbalancer.id,
                                  tls_certs[listener.client_crl_container_id]))
 
+        if (listener.protocol == constants.PROTOCOL_TERMINATED_HTTPS and
+                listener.tls_ciphers is not None):
+            ret_value['tls_ciphers'] = listener.tls_ciphers
+
         pools = []
         pool_gen = (pool for pool in listener.pools if
                     pool.provisioning_status != constants.PENDING_DELETE)
@@ -348,6 +351,8 @@ class JinjaTemplater(object):
         if (pool.tls_certificate_id and pool_tls_certs and
                 pool_tls_certs.get('client_cert')):
             ret_value['client_cert'] = pool_tls_certs.get('client_cert')
+        if pool.tls_enabled is True and pool.tls_ciphers is not None:
+            ret_value['tls_ciphers'] = pool.tls_ciphers
         if (pool.ca_tls_certificate_id and pool_tls_certs and
                 pool_tls_certs.get('ca_cert')):
             ret_value['ca_cert'] = pool_tls_certs.get('ca_cert')
@@ -394,7 +399,7 @@ class JinjaTemplater(object):
         """
         codes = None
         if monitor.expected_codes:
-            codes = '|'.join(self._expand_expected_codes(
+            codes = '|'.join(octavia_utils.expand_expected_codes(
                 monitor.expected_codes))
         return {
             'id': monitor.id,
@@ -475,25 +480,3 @@ class JinjaTemplater(object):
         # Spaces next
         value = re.sub(' ', '\\ ', value)
         return value
-
-    @staticmethod
-    def _expand_expected_codes(codes):
-        """Expand the expected code string in set of codes.
-
-        200-204 -> 200, 201, 202, 204
-        200, 203 -> 200, 203
-        """
-
-        retval = set()
-        for code in codes.replace(',', ' ').split(' '):
-            code = code.strip()
-
-            if not code:
-                continue
-            if '-' in code:
-                low, hi = code.split('-')[:2]
-                retval.update(
-                    str(i) for i in six.moves.xrange(int(low), int(hi) + 1))
-            else:
-                retval.add(code)
-        return sorted(retval)
