@@ -25,7 +25,6 @@ import re
 import netaddr
 from oslo_config import cfg
 import rfc3986
-import six
 from wsme import types as wtypes
 
 from octavia.common import constants
@@ -313,11 +312,11 @@ def sanitize_l7policy_api_args(l7policy, create=False):
     return l7policy
 
 
-def port_exists(port_id):
+def port_exists(port_id, context=None):
     """Raises an exception when a port does not exist."""
     network_driver = utils.get_network_driver()
     try:
-        port = network_driver.get_port(port_id)
+        port = network_driver.get_port(port_id, context=context)
     except Exception:
         raise exceptions.InvalidSubresource(resource='Port', id=port_id)
     return port
@@ -332,11 +331,11 @@ def check_port_in_use(port):
     return False
 
 
-def subnet_exists(subnet_id):
+def subnet_exists(subnet_id, context=None):
     """Raises an exception when a subnet does not exist."""
     network_driver = utils.get_network_driver()
     try:
-        subnet = network_driver.get_subnet(subnet_id)
+        subnet = network_driver.get_subnet(subnet_id, context=context)
     except Exception:
         raise exceptions.InvalidSubresource(resource='Subnet', id=subnet_id)
     return subnet
@@ -359,14 +358,15 @@ def qos_extension_enabled(network_driver):
             "VIP QoS policy is not allowed in this deployment."))
 
 
-def network_exists_optionally_contains_subnet(network_id, subnet_id=None):
+def network_exists_optionally_contains_subnet(network_id, subnet_id=None,
+                                              context=None):
     """Raises an exception when a network does not exist.
 
     If a subnet is provided, also validate the network contains that subnet.
     """
     network_driver = utils.get_network_driver()
     try:
-        network = network_driver.get_network(network_id)
+        network = network_driver.get_network(network_id, context=context)
     except Exception:
         raise exceptions.InvalidSubresource(resource='Network', id=network_id)
     if subnet_id:
@@ -376,10 +376,12 @@ def network_exists_optionally_contains_subnet(network_id, subnet_id=None):
     return network
 
 
-def network_allowed_by_config(network_id):
-    if CONF.networking.valid_vip_networks:
-        valid_networks = map(str.lower, CONF.networking.valid_vip_networks)
-        if network_id not in valid_networks:
+def network_allowed_by_config(network_id, valid_networks=None):
+    if CONF.networking.valid_vip_networks and not valid_networks:
+        valid_networks = CONF.networking.valid_vip_networks
+    if valid_networks:
+        valid_networks = map(str.lower, valid_networks)
+        if network_id.lower() not in valid_networks:
             raise exceptions.ValidationException(detail=_(
                 'Supplied VIP network_id is not allowed by the configuration '
                 'of this deployment.'))
@@ -419,7 +421,7 @@ def check_session_persistence(SP_dict):
 
 def ip_not_reserved(ip_address):
     ip_address = (
-        ipaddress.ip_address(six.text_type(ip_address)).exploded.upper())
+        ipaddress.ip_address(ip_address).exploded.upper())
     if ip_address in CONF.networking.reserved_ips:
         raise exceptions.InvalidOption(value=ip_address,
                                        option='member address')
