@@ -14,7 +14,7 @@
 
 """ Methods common to the controller work tasks."""
 
-import logging
+from oslo_log import log as logging
 
 from octavia.common import constants
 from octavia.db import api as db_apis
@@ -38,6 +38,24 @@ class TaskUtils(object):
         self.l7rule_repo = repo.L7RuleRepository()
         super(TaskUtils, self).__init__(**kwargs)
 
+    def unmark_amphora_health_busy(self, amphora_id):
+        """Unmark the amphora_health record busy for an amphora.
+
+        NOTE: This should only be called from revert methods.
+
+        :param amphora_id: The amphora id to unmark busy
+        """
+        LOG.debug('Unmarking health monitoring busy on amphora: %s',
+                  amphora_id)
+        try:
+            self.amp_health_repo.update(db_apis.get_session(),
+                                        amphora_id=amphora_id,
+                                        busy=False)
+        except Exception as e:
+            LOG.debug('Failed to update amphora health record %(amp)s '
+                      'due to: %(except)s',
+                      {'amp': amphora_id, 'except': str(e)})
+
     def mark_amphora_status_error(self, amphora_id):
         """Sets an amphora status to ERROR.
 
@@ -52,7 +70,7 @@ class TaskUtils(object):
         except Exception as e:
             LOG.error("Failed to update amphora %(amp)s "
                       "status to ERROR due to: "
-                      "%(except)s", {'amp': amphora_id, 'except': e})
+                      "%(except)s", {'amp': amphora_id, 'except': str(e)})
 
     def mark_health_mon_prov_status_error(self, health_mon_id):
         """Sets a health monitor provisioning status to ERROR.
@@ -68,7 +86,24 @@ class TaskUtils(object):
         except Exception as e:
             LOG.error("Failed to update health monitor %(health)s "
                       "provisioning status to ERROR due to: "
-                      "%(except)s", {'health': health_mon_id, 'except': e})
+                      "%(except)s",
+                      {'health': health_mon_id, 'except': str(e)})
+
+    def mark_l7policy_prov_status_active(self, l7policy_id):
+        """Sets a L7 policy provisioning status to ACTIVE.
+
+        NOTE: This should only be called from revert methods.
+
+        :param l7policy_id: L7 Policy ID to set provisioning status to ACTIVE
+        """
+        try:
+            self.l7policy_repo.update(db_apis.get_session(),
+                                      id=l7policy_id,
+                                      provisioning_status=constants.ACTIVE)
+        except Exception as e:
+            LOG.error("Failed to update l7policy %(l7p)s "
+                      "provisioning status to ACTIVE due to: "
+                      "%(except)s", {'l7p': l7policy_id, 'except': str(e)})
 
     def mark_l7policy_prov_status_error(self, l7policy_id):
         """Sets a L7 policy provisioning status to ERROR.
@@ -84,7 +119,7 @@ class TaskUtils(object):
         except Exception as e:
             LOG.error("Failed to update l7policy %(l7p)s "
                       "provisioning status to ERROR due to: "
-                      "%(except)s", {'l7p': l7policy_id, 'except': e})
+                      "%(except)s", {'l7p': l7policy_id, 'except': str(e)})
 
     def mark_l7rule_prov_status_error(self, l7rule_id):
         """Sets a L7 rule provisioning status to ERROR.
@@ -100,7 +135,7 @@ class TaskUtils(object):
         except Exception as e:
             LOG.error("Failed to update l7rule %(l7r)s "
                       "provisioning status to ERROR due to: "
-                      "%(except)s", {'l7r': l7rule_id, 'except': e})
+                      "%(except)s", {'l7r': l7rule_id, 'except': str(e)})
 
     def mark_listener_prov_status_error(self, listener_id):
         """Sets a listener provisioning status to ERROR.
@@ -116,7 +151,7 @@ class TaskUtils(object):
         except Exception as e:
             LOG.error("Failed to update listener %(list)s "
                       "provisioning status to ERROR due to: "
-                      "%(except)s", {'list': listener_id, 'except': e})
+                      "%(except)s", {'list': listener_id, 'except': str(e)})
 
     def mark_loadbalancer_prov_status_error(self, loadbalancer_id):
         """Sets a load balancer provisioning status to ERROR.
@@ -133,7 +168,7 @@ class TaskUtils(object):
         except Exception as e:
             LOG.error("Failed to update load balancer %(lb)s "
                       "provisioning status to ERROR due to: "
-                      "%(except)s", {'lb': loadbalancer_id, 'except': e})
+                      "%(except)s", {'lb': loadbalancer_id, 'except': str(e)})
 
     def mark_listener_prov_status_active(self, listener_id):
         """Sets a listener provisioning status to ACTIVE.
@@ -150,7 +185,7 @@ class TaskUtils(object):
         except Exception as e:
             LOG.error("Failed to update listener %(list)s "
                       "provisioning status to ACTIVE due to: "
-                      "%(except)s", {'list': listener_id, 'except': e})
+                      "%(except)s", {'list': listener_id, 'except': str(e)})
 
     def mark_pool_prov_status_active(self, pool_id):
         """Sets a pool provisioning status to ACTIVE.
@@ -166,7 +201,7 @@ class TaskUtils(object):
         except Exception as e:
             LOG.error("Failed to update pool %(pool)s provisioning status "
                       "to ACTIVE due to: %(except)s", {'pool': pool_id,
-                                                       'except': e})
+                                                       'except': str(e)})
 
     def mark_loadbalancer_prov_status_active(self, loadbalancer_id):
         """Sets a load balancer provisioning status to ACTIVE.
@@ -183,7 +218,7 @@ class TaskUtils(object):
         except Exception as e:
             LOG.error("Failed to update load balancer %(lb)s "
                       "provisioning status to ACTIVE due to: "
-                      "%(except)s", {'lb': loadbalancer_id, 'except': e})
+                      "%(except)s", {'lb': loadbalancer_id, 'except': str(e)})
 
     def mark_member_prov_status_error(self, member_id):
         """Sets a member provisioning status to ERROR.
@@ -199,7 +234,7 @@ class TaskUtils(object):
         except Exception as e:
             LOG.error("Failed to update member %(member)s "
                       "provisioning status to ERROR due to: "
-                      "%(except)s", {'member': member_id, 'except': e})
+                      "%(except)s", {'member': member_id, 'except': str(e)})
 
     def mark_pool_prov_status_error(self, pool_id):
         """Sets a pool provisioning status to ERROR.
@@ -215,4 +250,17 @@ class TaskUtils(object):
         except Exception as e:
             LOG.error("Failed to update pool %(pool)s "
                       "provisioning status to ERROR due to: "
-                      "%(except)s", {'pool': pool_id, 'except': e})
+                      "%(except)s", {'pool': pool_id, 'except': str(e)})
+
+    def get_current_loadbalancer_from_db(self, loadbalancer_id):
+        """Gets a Loadbalancer from db.
+
+        :param: loadbalancer_id: Load balancer ID which to get from db
+        """
+        try:
+            return self.loadbalancer_repo.get(db_apis.get_session(),
+                                              id=loadbalancer_id)
+        except Exception as e:
+            LOG.error("Failed to get loadbalancer %(loadbalancer)s "
+                      "due to: %(except)s",
+                      {'loadbalancer': loadbalancer_id, 'except': str(e)})
