@@ -110,7 +110,7 @@ class ControllerWorker(base_taskflow.BaseTaskFlowEngine):
 
             return create_amp_tf.storage.fetch('amphora')
         except Exception as e:
-            LOG.error('Failed to create an amphora due to: {}'.format(str(e)))
+            LOG.error('Failed to create an amphora due to: %s', str(e))
 
     @tenacity.retry(
         retry=tenacity.retry_if_exception_type(db_exceptions.NoResultFound),
@@ -1095,7 +1095,7 @@ class ControllerWorker(base_taskflow.BaseTaskFlowEngine):
         except Exception as e:
             with excutils.save_and_reraise_exception(reraise=False):
                 LOG.exception("LB %(lbid)s failover exception: %(exc)s",
-                              {'lbid': load_balancer_id, 'exc': e})
+                              {'lbid': load_balancer_id, 'exc': str(e)})
                 self._lb_repo.update(
                     db_apis.get_session(), load_balancer_id,
                     provisioning_status=constants.ERROR)
@@ -1110,7 +1110,8 @@ class ControllerWorker(base_taskflow.BaseTaskFlowEngine):
 
         amp = self._amphora_repo.get(db_apis.get_session(),
                                      id=amphora_id)
-        LOG.info("Start amphora cert rotation, amphora's id is: %s", amp.id)
+        LOG.info("Start amphora cert rotation, amphora's id is: %s",
+                 amphora_id)
 
         certrotation_amphora_tf = self._taskflow_load(
             self._amphora_flows.cert_rotate_amphora_flow(),
@@ -1120,6 +1121,8 @@ class ControllerWorker(base_taskflow.BaseTaskFlowEngine):
         with tf_logging.DynamicLoggingListener(certrotation_amphora_tf,
                                                log=LOG):
             certrotation_amphora_tf.run()
+        LOG.info("Finished amphora cert rotation, amphora's id was: %s",
+                 amphora_id)
 
     def update_amphora_agent_config(self, amphora_id):
         """Update the amphora agent configuration.
@@ -1149,3 +1152,5 @@ class ControllerWorker(base_taskflow.BaseTaskFlowEngine):
         with tf_logging.DynamicLoggingListener(update_amphora_tf,
                                                log=LOG):
             update_amphora_tf.run()
+        LOG.info("Finished amphora agent configuration update, amphora's id "
+                 "was: %s", amphora_id)
