@@ -56,6 +56,9 @@ class AmpListenersUpdate(BaseAmphoraTask):
         # in a failover flow with both amps failing. Skip it and let
         # health manager fix it.
         try:
+            # Make sure we have a fresh load balancer object
+            loadbalancer = self.loadbalancer_repo.get(db_apis.get_session(),
+                                                      id=loadbalancer.id)
             self.amphora_driver.update_amphora_listeners(
                 loadbalancer, amphora, timeout_dict)
         except Exception as e:
@@ -75,6 +78,9 @@ class AmphoraIndexListenerUpdate(BaseAmphoraTask):
         # in a failover flow with both amps failing. Skip it and let
         # health manager fix it.
         try:
+            # Make sure we have a fresh load balancer object
+            loadbalancer = self.loadbalancer_repo.get(db_apis.get_session(),
+                                                      id=loadbalancer.id)
             self.amphora_driver.update_amphora_listeners(
                 loadbalancer, amphorae[amphora_index], timeout_dict)
         except Exception as e:
@@ -448,6 +454,6 @@ class AmphoraConfigUpdate(BaseAmphoraTask):
             self.amphora_driver.update_amphora_agent_config(amphora,
                                                             agent_config)
         except driver_except.AmpDriverNotImplementedError:
-            LOG.error('Amphora {} does not support agent configuration '
+            LOG.error('Amphora %s does not support agent configuration '
                       'update. Please update the amphora image for this '
-                      'amphora. Skipping.'.format(amphora.id))
+                      'amphora. Skipping.', amphora.id)
