@@ -104,6 +104,12 @@ def create_listener(listener_dict, lb_id):
     if 'client_authentication' not in listener_dict:
         listener_dict['client_authentication'] = constants.CLIENT_AUTH_NONE
 
+    if (listener_dict['protocol'] == constants.PROTOCOL_TERMINATED_HTTPS and
+            ('tls_ciphers' not in listener_dict or
+             listener_dict['tls_ciphers'] is None)):
+        listener_dict['tls_ciphers'] = (
+            CONF.api_settings.default_listener_ciphers)
+
     if listener_dict.get('timeout_client_data') is None:
         listener_dict['timeout_client_data'] = (
             CONF.haproxy_amphora.timeout_client_data)
@@ -177,6 +183,8 @@ def create_pool(pool_dict, lb_id=None):
         prepped_members = []
         for member_dict in pool_dict.get('members'):
             prepped_members.append(create_member(member_dict, pool_dict['id']))
+    if pool_dict['tls_enabled'] is True and pool_dict['tls_ciphers'] is None:
+        pool_dict['tls_ciphers'] = CONF.api_settings.default_pool_ciphers
     pool_dict[constants.PROVISIONING_STATUS] = constants.PENDING_CREATE
     pool_dict[constants.OPERATING_STATUS] = constants.OFFLINE
     return pool_dict
