@@ -28,6 +28,7 @@ def list_opts():
          itertools.chain(octavia.common.config.core_opts)),
         ('api_settings', octavia.common.config.api_opts),
         ('amphora_agent', octavia.common.config.amphora_agent_opts),
+        ('compute', octavia.common.config.compute_opts),
         ('networking', octavia.common.config.networking_opts),
         ('oslo_messaging', octavia.common.config.oslo_messaging_opts),
         ('haproxy_amphora', octavia.common.config.haproxy_amphora_opts),
@@ -39,7 +40,6 @@ def list_opts():
             octavia.certificates.common.local.certgen_opts)),
         ('house_keeping', octavia.common.config.house_keeping_opts),
         ('keepalived_vrrp', octavia.common.config.keepalived_vrrp_opts),
-        ('anchor', octavia.common.config.anchor_opts),
         ('nova', octavia.common.config.nova_opts),
         ('neutron', octavia.common.config.neutron_opts),
         ('glance', octavia.common.config.glance_opts),
