@@ -12,6 +12,8 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from octavia.common import constants
+
 
 class MockNovaInterface(object):
     net_id = None
@@ -65,6 +67,52 @@ MOCK_DEVICE_ID2 = 'Moctavia124'
 MOCK_SECURITY_GROUP_ID = 'security-group-1'
 MOCK_SECURITY_GROUP_NAME = 'SecurityGroup1'
 
+MOCK_SECURITY_GROUP = {
+    "id": MOCK_SECURITY_GROUP_ID,
+    "name": MOCK_SECURITY_GROUP_NAME,
+    "tenant_id": MOCK_PROJECT_ID,
+    "description": "",
+    "security_group_rules": [{
+        "id": "85f1c72b-cdd4-484f-a9c8-b3205f4e6f53",
+        "tenant_id": MOCK_PROJECT_ID,
+        "security_group_id": MOCK_SECURITY_GROUP_ID,
+        "ethertype": "IPv4",
+        "direction": "ingress",
+        "protocol": "tcp",
+        "port_range_min": 80,
+        "port_range_max": 80,
+        "remote_ip_prefix": None,
+        "remote_group_id": None,
+        "description": "",
+        "tags": [],
+        "created_at": "2020-03-12T20:44:48Z",
+        "updated_at": "2020-03-12T20:44:48Z",
+        "revision_number": 0,
+        "project_id": MOCK_PROJECT_ID
+    }, {
+        "id": "aa16ae5f-eac2-40b5-994b-5169a06228a4",
+        "tenant_id": MOCK_PROJECT_ID,
+        "security_group_id": "6530d536-3083-4d5c-a4a9-272ac7b8f3de",
+        "ethertype": "IPv4",
+        "direction": "egress",
+        "protocol": None,
+        "port_range_min": None,
+        "port_range_max": None,
+        "remote_ip_prefix": None,
+        "remote_group_id": None,
+        "description": None,
+        "tags": [],
+        "created_at": "2020-03-12T20:43:31Z",
+        "updated_at": "2020-03-12T20:43:31Z",
+        "revision_number": 0,
+        "project_id": MOCK_PROJECT_ID,
+    }],
+    "tags": [],
+    "created_at": "2020-03-12T20:43:31Z",
+    "updated_at": "2020-03-12T20:44:48Z",
+    "revision_number": 3,
+    "project_id": MOCK_PROJECT_ID}
+
 MOCK_ADMIN_STATE_UP = True
 MOCK_STATUS = 'ACTIVE'
 MOCK_MTU = 1500
@@ -214,3 +262,22 @@ MOCK_NETWORK_IP_AVAILABILITY = {'network_ip_availability': (
      'total_ips': MOCK_NETWORK_TOTAL_IPS,
      'used_ips': MOCK_NETWORK_USED_IPS,
      'subnet_ip_availability': MOCK_SUBNET_IP_AVAILABILITY})}
+
+INVALID_LISTENER_POOL_PROTOCOL_MAP = {
+    constants.PROTOCOL_HTTP: [constants.PROTOCOL_HTTPS,
+                              constants.PROTOCOL_TCP,
+                              constants.PROTOCOL_TERMINATED_HTTPS,
+                              constants.PROTOCOL_UDP],
+    constants.PROTOCOL_HTTPS: [constants.PROTOCOL_HTTP,
+                               constants.PROTOCOL_TERMINATED_HTTPS,
+                               constants.PROTOCOL_UDP],
+    constants.PROTOCOL_TCP: [constants.PROTOCOL_TERMINATED_HTTPS,
+                             constants.PROTOCOL_UDP],
+    constants.PROTOCOL_TERMINATED_HTTPS: [constants.PROTOCOL_HTTPS,
+                                          constants.PROTOCOL_TCP,
+                                          constants.PROTOCOL_UDP],
+    constants.PROTOCOL_UDP: [constants.PROTOCOL_TCP,
+                             constants.PROTOCOL_HTTP,
+                             constants.PROTOCOL_HTTPS,
+                             constants.PROTOCOL_TERMINATED_HTTPS,
+                             constants.PROTOCOL_PROXY]}
