@@ -36,14 +36,16 @@ class TestRootController(base_db_test.OctaviaDBTestBase):
         self.conf.config(group='api_settings', auth_strategy=constants.NOAUTH)
 
     def _get_versions_with_config(self):
+        # Note: we need to set argv=() to stop the wsgi setup_app from
+        # pulling in the testing tool sys.argv
         app = pecan.testing.load_test_app({'app': pconfig.app,
-                                           'wsme': pconfig.wsme})
+                                           'wsme': pconfig.wsme}, argv=())
         return self.get(app=app, path='/').json.get('versions', None)
 
     def test_api_versions(self):
         versions = self._get_versions_with_config()
         version_ids = tuple(v.get('id') for v in versions)
-        self.assertEqual(14, len(version_ids))
+        self.assertEqual(17, len(version_ids))
         self.assertIn('v2.0', version_ids)
         self.assertIn('v2.1', version_ids)
         self.assertIn('v2.2', version_ids)
@@ -58,6 +60,9 @@ class TestRootController(base_db_test.OctaviaDBTestBase):
         self.assertIn('v2.11', version_ids)
         self.assertIn('v2.12', version_ids)
         self.assertIn('v2.13', version_ids)
+        self.assertIn('v2.14', version_ids)
+        self.assertIn('v2.15', version_ids)
+        self.assertIn('v2.16', version_ids)
 
         # Each version should have a 'self' 'href' to the API version URL
         # [{u'rel': u'self', u'href': u'http://localhost/v2'}]
