@@ -285,6 +285,58 @@ class TestHealthMonitor(base.BaseAPITest):
         hm_id_protocols = [(hm.get('id'), hm.get('type')) for hm in hms]
         self.assertIn((hm3.get('id'), hm3.get('type')), hm_id_protocols)
 
+    def test_get_all_unscoped_token(self):
+        project_id = uuidutils.generate_uuid()
+        lb1 = self.create_load_balancer(uuidutils.generate_uuid(), name='lb1',
+                                        project_id=project_id)
+        lb1_id = lb1.get('loadbalancer').get('id')
+        self.set_lb_status(lb1_id)
+        pool1 = self.create_pool(
+            lb1_id, constants.PROTOCOL_HTTP,
+            constants.LB_ALGORITHM_ROUND_ROBIN).get('pool')
+        self.set_lb_status(lb1_id)
+        pool2 = self.create_pool(
+            lb1_id, constants.PROTOCOL_HTTPS,
+            constants.LB_ALGORITHM_ROUND_ROBIN).get('pool')
+        self.set_lb_status(lb1_id)
+        self.create_health_monitor(
+            pool1.get('id'), constants.HEALTH_MONITOR_HTTP,
+            1, 1, 1, 1).get(self.root_tag)
+        self.set_lb_status(lb1_id)
+        self.create_health_monitor(
+            pool2.get('id'), constants.HEALTH_MONITOR_PING,
+            1, 1, 1, 1).get(self.root_tag)
+        self.set_lb_status(lb1_id)
+        self.create_health_monitor(
+            self.pool_id, constants.HEALTH_MONITOR_TCP,
+            1, 1, 1, 1).get(self.root_tag)
+        self.set_lb_status(self.lb_id)
+
+        auth_strategy = self.conf.conf.api_settings.get('auth_strategy')
+        self.conf.config(group='api_settings',
+                         auth_strategy=constants.KEYSTONE)
+        with mock.patch.object(octavia.common.context.Context, 'project_id',
+                               None):
+            override_credentials = {
+                'service_user_id': None,
+                'user_domain_id': None,
+                'is_admin_project': True,
+                'service_project_domain_id': None,
+                'service_project_id': None,
+                'roles': ['load-balancer_member'],
+                'user_id': None,
+                'is_admin': False,
+                'service_user_domain_id': None,
+                'project_domain_id': None,
+                'service_roles': [],
+                'project_id': None}
+            with mock.patch(
+                    "oslo_context.context.RequestContext.to_policy_values",
+                    return_value=override_credentials):
+                result = self.get(self.HMS_PATH, status=403).json
+        self.conf.config(group='api_settings', auth_strategy=auth_strategy)
+        self.assertEqual(self.NOT_AUTHORIZED_BODY, result)
+
     def test_get_all_non_admin_global_observer(self):
         project_id = uuidutils.generate_uuid()
         lb1 = self.create_load_balancer(uuidutils.generate_uuid(), name='lb1',
@@ -455,6 +507,64 @@ class TestHealthMonitor(base.BaseAPITest):
         hm_id_names_asc = [(hm.get('id'), hm.get('name')) for hm in hms_asc]
         self.assertEqual(hm_id_names_asc, list(reversed(hm_id_names_desc)))
 
+    def test_get_all_sorted_by_max_retries(self):
+        pool1 = self.create_pool(
+            self.lb_id,
+            constants.PROTOCOL_HTTP,
+            constants.LB_ALGORITHM_ROUND_ROBIN,
+            name='pool1').get('pool')
+        self.set_lb_status(self.lb_id)
+        pool2 = self.create_pool(
+            self.lb_id,
+            constants.PROTOCOL_HTTP,
+            constants.LB_ALGORITHM_ROUND_ROBIN,
+            name='pool2').get('pool')
+        self.set_lb_status(self.lb_id)
+        pool3 = self.create_pool(
+            self.lb_id,
+            constants.PROTOCOL_HTTP,
+            constants.LB_ALGORITHM_ROUND_ROBIN,
+            name='pool3').get('pool')
+        self.set_lb_status(self.lb_id)
+        hm1 = self.create_health_monitor(
+            pool1.get('id'), constants.HEALTH_MONITOR_HTTP,
+            1, 1, 1, 2, name='hm1').get(self.root_tag)
+        self.set_lb_status(self.lb_id)
+        hm2 = self.create_health_monitor(
+            pool2.get('id'), constants.HEALTH_MONITOR_PING,
+            1, 1, 1, 1, name='hm2').get(self.root_tag)
+        self.set_lb_status(self.lb_id)
+        hm3 = self.create_health_monitor(
+            pool3.get('id'), constants.HEALTH_MONITOR_TCP,
+            1, 1, 1, 3, name='hm3').get(self.root_tag)
+        self.set_lb_status(self.lb_id)
+
+        response = self.get(self.HMS_PATH, params={'sort': 'max_retries:desc'})
+        hms_desc = response.json.get(self.root_tag_list)
+        response = self.get(self.HMS_PATH, params={'sort': 'max_retries:asc'})
+        hms_asc = response.json.get(self.root_tag_list)
+
+        self.assertEqual(3, len(hms_desc))
+        self.assertEqual(3, len(hms_asc))
+
+        hm_id_names_desc = [(hm.get('id'), hm.get('name')) for hm in hms_desc]
+        hm_id_names_asc = [(hm.get('id'), hm.get('name')) for hm in hms_asc]
+        self.assertEqual(hm_id_names_asc, list(reversed(hm_id_names_desc)))
+
+        self.assertEqual(hm2[constants.MAX_RETRIES],
+                         hms_asc[0][constants.MAX_RETRIES])
+        self.assertEqual(hm1[constants.MAX_RETRIES],
+                         hms_asc[1][constants.MAX_RETRIES])
+        self.assertEqual(hm3[constants.MAX_RETRIES],
+                         hms_asc[2][constants.MAX_RETRIES])
+
+        self.assertEqual(hm3[constants.MAX_RETRIES],
+                         hms_desc[0][constants.MAX_RETRIES])
+        self.assertEqual(hm1[constants.MAX_RETRIES],
+                         hms_desc[1][constants.MAX_RETRIES])
+        self.assertEqual(hm2[constants.MAX_RETRIES],
+                         hms_desc[2][constants.MAX_RETRIES])
+
     def test_get_all_limited(self):
         pool1 = self.create_pool(
             self.lb_id,
