@@ -37,6 +37,23 @@ class ModelTestMixin(object):
             session.add(model)
         return model
 
+    def create_flavor_profile(self, session, **overrides):
+        kwargs = {'id': self.FAKE_UUID_1,
+                  'name': 'fake_profile',
+                  'provider_name': 'fake_provider',
+                  'flavor_data': "{'glance_image': 'ubuntu-16.04.03'}"}
+        kwargs.update(overrides)
+        return self._insert(session, models.FlavorProfile, kwargs)
+
+    def create_flavor(self, session, profile, **overrides):
+        kwargs = {'id': self.FAKE_UUID_1,
+                  'name': 'fake_flavor',
+                  'flavor_profile_id': profile,
+                  'description': 'fake flavor',
+                  'enabled': True}
+        kwargs.update(overrides)
+        return self._insert(session, models.Flavor, kwargs)
+
     def associate_amphora(self, load_balancer, amphora):
         load_balancer.amphorae.append(amphora)
 
@@ -70,7 +87,8 @@ class ModelTestMixin(object):
                   'lb_algorithm': constants.LB_ALGORITHM_LEAST_CONNECTIONS,
                   'provisioning_status': constants.ACTIVE,
                   'operating_status': constants.ONLINE,
-                  'enabled': True}
+                  'enabled': True,
+                  'tls_enabled': False}
         kwargs.update(overrides)
         return self._insert(session, models.Pool, kwargs)
 
@@ -175,6 +193,10 @@ class ModelTestMixin(object):
         kwargs.update(overrides)
         return self._insert(session, models.L7Rule, kwargs)
 
+    def create_listener_cidr(self, session, listener_id, cidr):
+        kwargs = {'listener_id': listener_id, 'cidr': cidr}
+        return self._insert(session, models.ListenerCidr, kwargs)
+
 
 class PoolModelTest(base.OctaviaDBTestBase, ModelTestMixin):
 
@@ -243,7 +265,7 @@ class PoolModelTest(base.OctaviaDBTestBase, ModelTestMixin):
         self.assertIsNotNone(new_pool.listeners)
         self.assertIsInstance(new_pool.listeners, list)
         self.assertIsInstance(new_pool.listeners[0], models.Listener)
-        self.assertIn(listener.id, [l.id for l in new_pool.listeners])
+        self.assertIn(listener.id, [li.id for li in new_pool.listeners])
 
 
 class MemberModelTest(base.OctaviaDBTestBase, ModelTestMixin):
@@ -765,7 +787,7 @@ class L7PolicyModelTest(base.OctaviaDBTestBase, ModelTestMixin):
         new_listener = self.session.query(models.Listener).filter_by(
             id=self.listener.id).first()
         self.assertIsInstance(new_pool.listeners, list)
-        self.assertIn(new_listener.id, [l.id for l in new_pool.listeners])
+        self.assertIn(new_listener.id, [li.id for li in new_pool.listeners])
         self.assertIsInstance(new_listener.pools, list)
         self.assertIn(new_pool.id, [p.id for p in new_listener.pools])
 
@@ -780,7 +802,7 @@ class L7PolicyModelTest(base.OctaviaDBTestBase, ModelTestMixin):
         new_listener = self.session.query(models.Listener).filter_by(
             id=self.listener.id).first()
         self.assertIsInstance(new_pool.listeners, list)
-        self.assertNotIn(new_listener.id, [l.id for l in new_pool.listeners])
+        self.assertNotIn(new_listener.id, [li.id for li in new_pool.listeners])
         self.assertIsInstance(new_listener.pools, list)
         self.assertNotIn(new_pool.id, [p.id for p in new_listener.pools])
 
@@ -796,7 +818,7 @@ class L7PolicyModelTest(base.OctaviaDBTestBase, ModelTestMixin):
         new_listener = self.session.query(models.Listener).filter_by(
             id=self.listener.id).first()
         self.assertIsInstance(new_pool.listeners, list)
-        self.assertNotIn(new_listener.id, [l.id for l in new_pool.listeners])
+        self.assertNotIn(new_listener.id, [li.id for li in new_pool.listeners])
         self.assertIsInstance(new_listener.pools, list)
         self.assertNotIn(new_pool.id, [p.id for p in new_listener.pools])
 
@@ -875,6 +897,8 @@ class TestDataModelConversionTest(base.OctaviaDBTestBase, ModelTestMixin):
             redirect_pool_id=self.pool.id)
         self.l7rule = self.create_l7rule(self.session,
                                          l7policy_id=self.l7policy.id)
+        self.listener_cidr = self.create_listener_cidr(
+            self.session, listener_id=self.listener.id, cidr='10.0.1.0/24')
 
     @staticmethod
     def _get_unique_key(obj):
@@ -889,6 +913,8 @@ class TestDataModelConversionTest(base.OctaviaDBTestBase, ModelTestMixin):
             return obj.__class__.__name__ + obj.pool_id
         elif obj.__class__.__name__ in ['ListenerStatistics']:
             return obj.__class__.__name__ + obj.listener_id + obj.amphora_id
+        elif obj.__class__.__name__ in ['ListenerCidr']:
+            return obj.__class__.__name__ + obj.listener_id + obj.cidr
         elif obj.__class__.__name__ in ['VRRPGroup', 'Vip']:
             return obj.__class__.__name__ + obj.load_balancer_id
         elif obj.__class__.__name__ in ['AmphoraHealth']:
@@ -954,6 +980,8 @@ class TestDataModelConversionTest(base.OctaviaDBTestBase, ModelTestMixin):
                          self.l7policy.to_data_model()._get_unique_key())
         self.assertEqual(self._get_unique_key(self.l7rule),
                          self.l7rule.to_data_model()._get_unique_key())
+        self.assertEqual(self._get_unique_key(self.listener_cidr),
+                         self.listener_cidr.to_data_model()._get_unique_key())
 
     def test_graph_completeness(self):
         # Generate equivalent graphs starting arbitrarily from different
@@ -1715,3 +1743,45 @@ class TestDataModelManipulations(base.OctaviaDBTestBase, ModelTestMixin):
         self.assertEqual(l7p.redirect_pool, new_pool)
         self.assertIn(new_pool, listener.pools)
         self.assertIn(listener, new_pool.listeners)
+
+
+class FlavorModelTest(base.OctaviaDBTestBase, ModelTestMixin):
+
+    def setUp(self):
+        super(FlavorModelTest, self).setUp()
+        self.profile = self.create_flavor_profile(self.session)
+
+    def test_create(self):
+        flavor = self.create_flavor(self.session, self.profile.id)
+        self.assertIsNotNone(flavor.id)
+
+    def test_delete(self):
+        flavor = self.create_flavor(self.session, self.profile.id)
+        self.assertIsNotNone(flavor.id)
+        id = flavor.id
+
+        with self.session.begin():
+            self.session.delete(flavor)
+            self.session.flush()
+        new_flavor = self.session.query(
+            models.Flavor).filter_by(id=id).first()
+        self.assertIsNone(new_flavor)
+
+
+class FlavorProfileModelTest(base.OctaviaDBTestBase, ModelTestMixin):
+
+    def test_create(self):
+        fp = self.create_flavor_profile(self.session)
+        self.assertIsNotNone(fp.id)
+
+    def test_delete(self):
+        fp = self.create_flavor_profile(self.session)
+        self.assertIsNotNone(fp.id)
+        id = fp.id
+
+        with self.session.begin():
+            self.session.delete(fp)
+            self.session.flush()
+        new_fp = self.session.query(
+            models.FlavorProfile).filter_by(id=id).first()
+        self.assertIsNone(new_fp)
