@@ -11,8 +11,7 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-
-import mock
+from unittest import mock
 
 from octavia.amphorae.backends.agent.api_server import haproxy_compatibility
 from octavia.common import constants
@@ -99,6 +98,15 @@ class HAProxyCompatTestCase(base.TestCase):
         self.assertEqual(1, major)
         self.assertEqual(6, minor)
 
+    @mock.patch('subprocess.check_output')
+    def test_get_haproxy_versions_devel(self, mock_process):
+        mock_process.return_value = (
+            b"HA-Proxy version 2.3-dev0 2019/11/25 - https://haproxy.org/\n"
+            b"Some other data here <test@example.com>\n")
+        major, minor = haproxy_compatibility.get_haproxy_versions()
+        self.assertEqual(2, major)
+        self.assertEqual(3, minor)
+
     @mock.patch('octavia.amphorae.backends.agent.api_server.'
                 'haproxy_compatibility.get_haproxy_versions')
     def test_process_cfg_for_version_compat(self, mock_get_version):
