@@ -11,14 +11,12 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
-
 import ipaddress
 import os
 import shutil
+from unittest import mock
 
-import mock
 from oslo_config import fixture as oslo_fixture
-import six
 
 from octavia.amphorae.backends.agent.api_server import osutils
 from octavia.common import config
@@ -44,9 +42,13 @@ class TestOSUtils(base.TestCase):
                         return_value='rhel'):
             self.rh_os_util = osutils.BaseOS.get_os_util()
 
-        with mock.patch('distro.id',
-                        return_value='centos'):
-            self.centos_os_util = osutils.BaseOS.get_os_util()
+        with mock.patch('distro.id', return_value='centos'):
+            with mock.patch('distro.version', return_value='8'):
+                self.centos_os_util = osutils.BaseOS.get_os_util()
+
+        with mock.patch('distro.id', return_value='centos'):
+            with mock.patch('distro.version', return_value='7'):
+                self.centos7_os_util = osutils.BaseOS.get_os_util()
 
     def test_get_os_util(self):
         with mock.patch('distro.id',
@@ -287,8 +289,14 @@ class TestOSUtils(base.TestCase):
 
     def test_cmd_get_version_of_installed_package_mapped(self):
         package_name = 'haproxy'
-        centos_cmd = "rpm -q --queryformat %{VERSION} haproxy18"
+        centos7_cmd = "rpm -q --queryformat %{VERSION} haproxy18"
 
+        returned_centos7_cmd = (
+            self.centos7_os_util.cmd_get_version_of_installed_package(
+                package_name))
+        self.assertEqual(centos7_cmd, returned_centos7_cmd)
+
+        centos_cmd = "rpm -q --queryformat %{VERSION} haproxy"
         returned_centos_cmd = (
             self.centos_os_util.cmd_get_version_of_installed_package(
                 package_name))
@@ -313,13 +321,13 @@ class TestOSUtils(base.TestCase):
         # matches the result of any arbitrary IPv4->prefixlen conversion
         SUBNET_CIDR_IPV6 = u'2001:db8::/70'
 
-        ip = ipaddress.ip_address(six.text_type(FIXED_IP))
+        ip = ipaddress.ip_address(FIXED_IP)
         network = ipaddress.ip_network(SUBNET_CIDR)
         broadcast = network.broadcast_address.exploded
         netmask = network.netmask.exploded
         netmask_prefix = utils.netmask_to_prefix(netmask)
 
-        ipv6 = ipaddress.ip_address(six.text_type(FIXED_IP_IPV6))
+        ipv6 = ipaddress.ip_address(FIXED_IP_IPV6)
         networkv6 = ipaddress.ip_network(SUBNET_CIDR_IPV6)
         broadcastv6 = networkv6.broadcast_address.exploded
         netmaskv6 = networkv6.prefixlen
@@ -407,15 +415,14 @@ class TestOSUtils(base.TestCase):
         NEXTHOP = u'192.0.2.1'
         DEST = u'198.51.100.0/24'
         host_routes = [
-            {'nexthop': NEXTHOP,
-             'destination': str(ipaddress.ip_network(DEST))}
+            {'nexthop': NEXTHOP, 'destination': ipaddress.ip_network(DEST)}
         ]
         FIXED_IP_IPV6 = u'2001:db8::2'
         NEXTHOP_IPV6 = u'2001:db8::1'
         DEST_IPV6 = u'2001:db8:51:100::/64'
         host_routes_ipv6 = [
             {'nexthop': NEXTHOP_IPV6,
-             'destination': str(ipaddress.ip_network(DEST_IPV6))}
+             'destination': ipaddress.ip_network(DEST_IPV6)}
         ]
         ip_addr = {'ip_address': FIXED_IP, 'host_routes': host_routes}
         ipv6_addr = {'ip_address': FIXED_IP_IPV6,
