@@ -11,11 +11,10 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 #    under the License.
-
 import os
 import subprocess
+from unittest import mock
 
-import mock
 from oslo_config import cfg
 from oslo_config import fixture as oslo_fixture
 from oslo_utils import uuidutils
@@ -329,8 +328,8 @@ class TestUtil(base.TestCase):
         handle = m()
         handle.write.assert_called_once_with(cmd)
         mock_makedirs.assert_has_calls(
-            [mock.call(util.keepalived_dir()),
-             mock.call(util.keepalived_check_scripts_dir())])
+            [mock.call(util.keepalived_dir(), exist_ok=True),
+             mock.call(util.keepalived_check_scripts_dir(), exist_ok=True)])
 
     @mock.patch('octavia.amphorae.backends.agent.api_server.util.config_path')
     def test_get_haproxy_vip_addresses(self, mock_cfg_path):
