@@ -11,10 +11,9 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-
 import signal
+from unittest import mock
 
-import mock
 from oslo_config import cfg
 from oslo_config import fixture as oslo_fixture
 
