@@ -11,10 +11,8 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
-
 import signal
-
-import mock
+from unittest import mock
 
 from octavia.cmd import health_manager
 from octavia.tests.unit import base
