@@ -45,7 +45,6 @@ class TestHaproxyCfg(base.TestCase):
             CONF.haproxy_amphora.base_cert_dir,
             'sample_listener_id_1/sample_listener_id_1.pem')
         fe = ("frontend sample_listener_id_1\n"
-              "    option httplog\n"
               "    maxconn {maxconn}\n"
               "    redirect scheme https if !{{ ssl_fc }}\n"
               "    bind 10.0.0.2:443 "
@@ -55,7 +54,7 @@ class TestHaproxyCfg(base.TestCase):
               "certs/sample_listener_id_1/SHA_ID.pem\n"
               "    mode http\n"
               "    default_backend sample_pool_id_1\n"
-              "    timeout client 50000\n\n").format(
+              "    timeout client 50000\n").format(
             maxconn=constants.HAPROXY_MAX_MAXCONN,
             crt_list=FAKE_CRT_LIST_FILENAME)
         be = ("backend sample_pool_id_1\n"
@@ -95,14 +94,13 @@ class TestHaproxyCfg(base.TestCase):
             CONF.haproxy_amphora.base_cert_dir,
             'sample_listener_id_1/sample_listener_id_1.pem')
         fe = ("frontend sample_listener_id_1\n"
-              "    option httplog\n"
               "    maxconn {maxconn}\n"
               "    redirect scheme https if !{{ ssl_fc }}\n"
               "    bind 10.0.0.2:443 "
               "ssl crt-list {crt_list}\n"
               "    mode http\n"
               "    default_backend sample_pool_id_1\n"
-              "    timeout client 50000\n\n").format(
+              "    timeout client 50000\n").format(
             maxconn=constants.HAPROXY_MAX_MAXCONN,
             crt_list=FAKE_CRT_LIST_FILENAME)
         be = ("backend sample_pool_id_1\n"
@@ -189,12 +187,11 @@ class TestHaproxyCfg(base.TestCase):
 
     def test_render_template_custom_timeouts(self):
         fe = ("frontend sample_listener_id_1\n"
-              "    option httplog\n"
               "    maxconn {maxconn}\n"
               "    bind 10.0.0.2:80\n"
               "    mode http\n"
               "    default_backend sample_pool_id_1\n"
-              "    timeout client 2\n\n").format(
+              "    timeout client 2\n").format(
             maxconn=constants.HAPROXY_MAX_MAXCONN)
         be = ("backend sample_pool_id_1\n"
               "    mode http\n"
@@ -225,12 +222,11 @@ class TestHaproxyCfg(base.TestCase):
 
     def test_render_template_null_timeouts(self):
         fe = ("frontend sample_listener_id_1\n"
-              "    option httplog\n"
               "    maxconn {maxconn}\n"
               "    bind 10.0.0.2:80\n"
               "    mode http\n"
               "    default_backend sample_pool_id_1\n"
-              "    timeout client 50000\n\n").format(
+              "    timeout client 50000\n").format(
             maxconn=constants.HAPROXY_MAX_MAXCONN)
         be = ("backend sample_pool_id_1\n"
               "    mode http\n"
@@ -289,13 +285,16 @@ class TestHaproxyCfg(base.TestCase):
 
     def test_render_template_https_real_monitor(self):
         fe = ("frontend sample_listener_id_1\n"
-              "    option tcplog\n"
               "    maxconn {maxconn}\n"
               "    bind 10.0.0.2:443\n"
               "    mode tcp\n"
               "    default_backend sample_pool_id_1\n"
-              "    timeout client 50000\n\n").format(
+              "    timeout client 50000\n").format(
             maxconn=constants.HAPROXY_MAX_MAXCONN)
+        lg = ("    log-format 12345\\ sample_loadbalancer_id_1\\ %f\\ "
+              "%ci\\ %cp\\ %t\\ -\\ -\\ %B\\ %U\\ "
+              "%[ssl_c_verify]\\ %{+Q}[ssl_c_s_dn]\\ %b\\ %s\\ %Tt\\ "
+              "%tsc\n\n")
         be = ("backend sample_pool_id_1\n"
               "    mode tcp\n"
               "    balance roundrobin\n"
@@ -318,17 +317,20 @@ class TestHaproxyCfg(base.TestCase):
             sample_configs_split.sample_amphora_tuple(),
             sample_configs_split.sample_listener_tuple(proto='HTTPS'))
         self.assertEqual(sample_configs_split.sample_base_expected_config(
-            frontend=fe, backend=be), rendered_obj)
+            frontend=fe, logging=lg, backend=be), rendered_obj)
 
     def test_render_template_https_hello_monitor(self):
         fe = ("frontend sample_listener_id_1\n"
-              "    option tcplog\n"
               "    maxconn {maxconn}\n"
               "    bind 10.0.0.2:443\n"
               "    mode tcp\n"
               "    default_backend sample_pool_id_1\n"
-              "    timeout client 50000\n\n").format(
+              "    timeout client 50000\n").format(
             maxconn=constants.HAPROXY_MAX_MAXCONN)
+        lg = ("    log-format 12345\\ sample_loadbalancer_id_1\\ %f\\ "
+              "%ci\\ %cp\\ %t\\ -\\ -\\ %B\\ %U\\ "
+              "%[ssl_c_verify]\\ %{+Q}[ssl_c_s_dn]\\ %b\\ %s\\ %Tt\\ "
+              "%tsc\n\n")
         be = ("backend sample_pool_id_1\n"
               "    mode tcp\n"
               "    balance roundrobin\n"
@@ -351,7 +353,7 @@ class TestHaproxyCfg(base.TestCase):
             sample_configs_split.sample_listener_tuple(
                 proto='HTTPS', monitor_proto='TLS-HELLO'))
         self.assertEqual(sample_configs_split.sample_base_expected_config(
-            frontend=fe, backend=be), rendered_obj)
+            frontend=fe, logging=lg, backend=be), rendered_obj)
 
     def test_render_template_no_monitor_http(self):
         be = ("backend sample_pool_id_1\n"
@@ -425,13 +427,16 @@ class TestHaproxyCfg(base.TestCase):
 
     def test_render_template_no_monitor_https(self):
         fe = ("frontend sample_listener_id_1\n"
-              "    option tcplog\n"
               "    maxconn {maxconn}\n"
               "    bind 10.0.0.2:443\n"
               "    mode tcp\n"
               "    default_backend sample_pool_id_1\n"
-              "    timeout client 50000\n\n").format(
+              "    timeout client 50000\n").format(
             maxconn=constants.HAPROXY_MAX_MAXCONN)
+        lg = ("    log-format 12345\\ sample_loadbalancer_id_1\\ %f\\ "
+              "%ci\\ %cp\\ %t\\ -\\ -\\ %B\\ %U\\ "
+              "%[ssl_c_verify]\\ %{+Q}[ssl_c_s_dn]\\ %b\\ %s\\ %Tt\\ "
+              "%tsc\n\n")
         be = ("backend sample_pool_id_1\n"
               "    mode tcp\n"
               "    balance roundrobin\n"
@@ -450,7 +455,7 @@ class TestHaproxyCfg(base.TestCase):
             sample_configs_split.sample_listener_tuple(
                 proto='HTTPS', monitor=False))
         self.assertEqual(sample_configs_split.sample_base_expected_config(
-            frontend=fe, backend=be), rendered_obj)
+            frontend=fe, logging=lg, backend=be), rendered_obj)
 
     def test_render_template_health_monitor_http_check(self):
         be = ("backend sample_pool_id_1\n"
@@ -481,13 +486,16 @@ class TestHaproxyCfg(base.TestCase):
 
     def test_render_template_no_persistence_https(self):
         fe = ("frontend sample_listener_id_1\n"
-              "    option tcplog\n"
               "    maxconn {maxconn}\n"
               "    bind 10.0.0.2:443\n"
               "    mode tcp\n"
               "    default_backend sample_pool_id_1\n"
-              "    timeout client 50000\n\n").format(
+              "    timeout client 50000\n").format(
             maxconn=constants.HAPROXY_MAX_MAXCONN)
+        lg = ("    log-format 12345\\ sample_loadbalancer_id_1\\ %f\\ "
+              "%ci\\ %cp\\ %t\\ -\\ -\\ %B\\ %U\\ "
+              "%[ssl_c_verify]\\ %{+Q}[ssl_c_s_dn]\\ %b\\ %s\\ %Tt\\ "
+              "%tsc\n\n")
         be = ("backend sample_pool_id_1\n"
               "    mode tcp\n"
               "    balance roundrobin\n"
@@ -503,7 +511,7 @@ class TestHaproxyCfg(base.TestCase):
             sample_configs_split.sample_listener_tuple(
                 proto='HTTPS', monitor=False, persistence=False))
         self.assertEqual(sample_configs_split.sample_base_expected_config(
-            frontend=fe, backend=be), rendered_obj)
+            frontend=fe, logging=lg, backend=be), rendered_obj)
 
     def test_render_template_no_persistence_http(self):
         be = ("backend sample_pool_id_1\n"
@@ -579,13 +587,16 @@ class TestHaproxyCfg(base.TestCase):
 
     def test_render_template_unlimited_connections(self):
         fe = ("frontend sample_listener_id_1\n"
-              "    option tcplog\n"
               "    maxconn {maxconn}\n"
               "    bind 10.0.0.2:443\n"
               "    mode tcp\n"
               "    default_backend sample_pool_id_1\n"
-              "    timeout client 50000\n\n").format(
+              "    timeout client 50000\n").format(
             maxconn=constants.HAPROXY_MAX_MAXCONN)
+        lg = ("    log-format 12345\\ sample_loadbalancer_id_1\\ %f\\ "
+              "%ci\\ %cp\\ %t\\ -\\ -\\ %B\\ %U\\ "
+              "%[ssl_c_verify]\\ %{+Q}[ssl_c_s_dn]\\ %b\\ %s\\ %Tt\\ "
+              "%tsc\n\n")
         be = ("backend sample_pool_id_1\n"
               "    mode tcp\n"
               "    balance roundrobin\n"
@@ -604,16 +615,19 @@ class TestHaproxyCfg(base.TestCase):
             sample_configs_split.sample_listener_tuple(
                 proto='HTTPS', monitor=False))
         self.assertEqual(sample_configs_split.sample_base_expected_config(
-            frontend=fe, backend=be), rendered_obj)
+            frontend=fe, logging=lg, backend=be), rendered_obj)
 
     def test_render_template_limited_connections(self):
         fe = ("frontend sample_listener_id_1\n"
-              "    option tcplog\n"
               "    maxconn 2014\n"
               "    bind 10.0.0.2:443\n"
               "    mode tcp\n"
               "    default_backend sample_pool_id_1\n"
-              "    timeout client 50000\n\n")
+              "    timeout client 50000\n")
+        lg = ("    log-format 12345\\ sample_loadbalancer_id_1\\ %f\\ "
+              "%ci\\ %cp\\ %t\\ -\\ -\\ %B\\ %U\\ "
+              "%[ssl_c_verify]\\ %{+Q}[ssl_c_s_dn]\\ %b\\ %s\\ %Tt\\ "
+              "%tsc\n\n")
         be = ("backend sample_pool_id_1\n"
               "    mode tcp\n"
               "    balance roundrobin\n"
@@ -632,11 +646,11 @@ class TestHaproxyCfg(base.TestCase):
             sample_configs_split.sample_listener_tuple(
                 proto='HTTPS', monitor=False, connection_limit=2014))
         self.assertEqual(sample_configs_split.sample_base_expected_config(
-            frontend=fe, backend=be, global_opts=g_opts), rendered_obj)
+            frontend=fe, logging=lg, backend=be, global_opts=g_opts),
+            rendered_obj)
 
     def test_render_template_l7policies(self):
         fe = ("frontend sample_listener_id_1\n"
-              "    option httplog\n"
               "    maxconn {maxconn}\n"
               "    bind 10.0.0.2:80\n"
               "    mode http\n"
@@ -660,7 +674,7 @@ class TestHaproxyCfg(base.TestCase):
               "    redirect code 302 prefix https://example.com if "
               "!sample_l7rule_id_2 sample_l7rule_id_3\n"
               "    default_backend sample_pool_id_1\n"
-              "    timeout client 50000\n\n").format(
+              "    timeout client 50000\n").format(
             maxconn=constants.HAPROXY_MAX_MAXCONN)
         be = ("backend sample_pool_id_1\n"
               "    mode http\n"
@@ -967,35 +981,6 @@ class TestHaproxyCfg(base.TestCase):
         self.assertEqual(self.jinja_cfg._escape_haproxy_config_string(
             'string\\ with\\ all'), 'string\\\\\\ with\\\\\\ all')
 
-    def test_expand_expected_codes(self):
-        exp_codes = ''
-        self.assertEqual(self.jinja_cfg._expand_expected_codes(exp_codes),
-                         set([]))
-        exp_codes = '200'
-        self.assertEqual(
-            self.jinja_cfg._expand_expected_codes(exp_codes), set(['200']))
-        exp_codes = '200, 201'
-        self.assertEqual(self.jinja_cfg._expand_expected_codes(exp_codes),
-                         set(['200', '201']))
-        exp_codes = '200, 201,202'
-        self.assertEqual(self.jinja_cfg._expand_expected_codes(exp_codes),
-                         set(['200', '201', '202']))
-        exp_codes = '200-202'
-        self.assertEqual(self.jinja_cfg._expand_expected_codes(exp_codes),
-                         set(['200', '201', '202']))
-        exp_codes = '200-202, 205'
-        self.assertEqual(self.jinja_cfg._expand_expected_codes(exp_codes),
-                         set(['200', '201', '202', '205']))
-        exp_codes = '200, 201-203'
-        self.assertEqual(self.jinja_cfg._expand_expected_codes(exp_codes),
-                         set(['200', '201', '202', '203']))
-        exp_codes = '200, 201-203, 205'
-        self.assertEqual(self.jinja_cfg._expand_expected_codes(exp_codes),
-                         set(['200', '201', '202', '203', '205']))
-        exp_codes = '201-200, 205'
-        self.assertEqual(
-            self.jinja_cfg._expand_expected_codes(exp_codes), set(['205']))
-
     def test_render_template_no_log(self):
         j_cfg = jinja_cfg.JinjaTemplater(
             base_amp_path='/var/lib/octavia',
@@ -1014,7 +999,7 @@ class TestHaproxyCfg(base.TestCase):
         )
         self.assertEqual(
             sample_configs_split.sample_base_expected_config(
-                defaults=defaults),
+                defaults=defaults, logging="\n"),
             rendered_obj)
 
     def test_http_reuse(self):
@@ -1078,7 +1063,6 @@ class TestHaproxyCfg(base.TestCase):
             base_amp_path='/var/lib/octavia',
             base_crt_dir='/var/lib/octavia/certs')
         fe = ("frontend sample_listener_id_1\n"
-              "    option httplog\n"
               "    maxconn 1000000\n"
               "    redirect scheme https if !{ ssl_fc }\n"
               "    bind 10.0.0.2:443\n"
@@ -1114,7 +1098,7 @@ class TestHaproxyCfg(base.TestCase):
               "if sample_l7rule_id_7 !sample_l7rule_id_8 !sample_l7rule_id_9 "
               "!sample_l7rule_id_10 sample_l7rule_id_11\n"
               "    default_backend sample_pool_id_1\n"
-              "    timeout client 50000\n\n")
+              "    timeout client 50000\n")
         be = ("backend sample_pool_id_1\n"
               "    mode http\n"
               "    balance roundrobin\n"
