@@ -40,7 +40,7 @@ class TestLvsCfg(base.TestCase):
                "# Configuration for Listener sample_listener_id_1\n\n"
                "net_namespace amphora-haproxy\n\n"
                "virtual_server 10.0.0.2 80 {\n"
-               "    lb_algo rr\n"
+               "    lb_algo wrr\n"
                "    lb_kind NAT\n"
                "    protocol UDP\n"
                "    persistence_timeout 33\n"
@@ -86,7 +86,7 @@ class TestLvsCfg(base.TestCase):
                "# Configuration for Listener sample_listener_id_1\n\n"
                "net_namespace amphora-haproxy\n\n"
                "virtual_server 10.0.0.2 80 {\n"
-               "    lb_algo rr\n"
+               "    lb_algo wrr\n"
                "    lb_kind NAT\n"
                "    protocol UDP\n"
                "    delay_loop 30\n"
@@ -129,7 +129,7 @@ class TestLvsCfg(base.TestCase):
                "# Configuration for Listener sample_listener_id_1\n\n"
                "net_namespace amphora-haproxy\n\n"
                "virtual_server 10.0.0.2 80 {\n"
-               "    lb_algo rr\n"
+               "    lb_algo wrr\n"
                "    lb_kind NAT\n"
                "    protocol UDP\n"
                "    delay_loop 30\n"
@@ -172,7 +172,7 @@ class TestLvsCfg(base.TestCase):
                "# Configuration for Listener sample_listener_id_1\n\n"
                "net_namespace amphora-haproxy\n\n"
                "virtual_server 10.0.0.2 80 {\n"
-               "    lb_algo rr\n"
+               "    lb_algo wrr\n"
                "    lb_kind NAT\n"
                "    protocol UDP\n"
                "    delay_loop 30\n"
@@ -227,7 +227,7 @@ class TestLvsCfg(base.TestCase):
                "# Configuration for Listener sample_listener_id_1\n\n"
                "net_namespace amphora-haproxy\n\n"
                "virtual_server 10.0.0.2 80 {\n"
-               "    lb_algo rr\n"
+               "    lb_algo wrr\n"
                "    lb_kind NAT\n"
                "    protocol UDP\n\n\n"
                "    # Configuration for Pool sample_pool_id_0\n"
@@ -245,7 +245,7 @@ class TestLvsCfg(base.TestCase):
                "# Configuration for Listener sample_listener_id_1\n\n"
                "net_namespace amphora-haproxy\n\n"
                "virtual_server 10.0.0.2 80 {\n"
-               "    lb_algo rr\n"
+               "    lb_algo wrr\n"
                "    lb_kind NAT\n"
                "    protocol UDP\n\n\n"
                "    # Pool sample_pool_id_1 is disabled\n"
@@ -347,7 +347,7 @@ class TestLvsCfg(base.TestCase):
                "# Configuration for Listener sample_listener_id_1\n\n"
                "net_namespace amphora-haproxy\n\n"
                "virtual_server 10.0.0.2 80 {\n"
-               "    lb_algo rr\n"
+               "    lb_algo wrr\n"
                "    lb_kind NAT\n"
                "    protocol UDP\n"
                "    delay_loop 30\n"
@@ -408,7 +408,7 @@ class TestLvsCfg(base.TestCase):
                "# Configuration for Listener sample_listener_id_1\n\n"
                "net_namespace amphora-haproxy\n\n"
                "virtual_server 10.0.0.2 80 {\n"
-               "    lb_algo rr\n"
+               "    lb_algo wrr\n"
                "    lb_kind NAT\n"
                "    protocol UDP\n"
                "    delay_loop 30\n"
