@@ -352,7 +352,6 @@ RET_LISTENER_TLS = {
 RET_LISTENER_TLS_SNI = {
     'id': 'sample_listener_id_1',
     'protocol_port': '443',
-    'protocol': 'http',
     'protocol': 'TERMINATED_HTTPS',
     'default_pool': RET_POOL_1,
     'connection_limit': constants.HAPROXY_MAX_MAXCONN,
@@ -612,8 +611,9 @@ def sample_listener_tuple(proto=None, monitor=True, alloc_default_pool=True,
                           tls=False, sni=False, peer_port=None, topology=None,
                           l7=False, enabled=True, insert_headers=None,
                           be_proto=None, monitor_ip_port=False,
-                          monitor_proto=None, backup_member=False,
-                          disabled_member=False, connection_limit=-1,
+                          monitor_proto=None, monitor_expected_codes=None,
+                          backup_member=False, disabled_member=False,
+                          connection_limit=-1,
                           timeout_client_data=50000,
                           timeout_member_connect=5000,
                           timeout_member_data=50000,
@@ -626,9 +626,9 @@ def sample_listener_tuple(proto=None, monitor=True, alloc_default_pool=True,
                           provisioning_status=constants.ACTIVE):
     proto = 'HTTP' if proto is None else proto
     if be_proto is None:
-        be_proto = 'HTTP' if proto is 'TERMINATED_HTTPS' else proto
+        be_proto = 'HTTP' if proto == 'TERMINATED_HTTPS' else proto
     topology = 'SINGLE' if topology is None else topology
-    port = '443' if proto is 'HTTPS' or proto is 'TERMINATED_HTTPS' else '80'
+    port = '443' if proto in ['HTTPS', 'TERMINATED_HTTPS'] else '80'
     peer_port = 1024 if peer_port is None else peer_port
     insert_headers = insert_headers or {}
     in_listener = collections.namedtuple(
@@ -698,6 +698,7 @@ def sample_listener_tuple(proto=None, monitor=True, alloc_default_pool=True,
             persistence_granularity=persistence_granularity,
             monitor_ip_port=monitor_ip_port,
             monitor_proto=monitor_proto,
+            monitor_expected_codes=monitor_expected_codes,
             pool_cert=pool_cert,
             pool_ca_cert=pool_ca_cert,
             pool_crl=pool_crl,
@@ -779,7 +780,8 @@ def sample_pool_tuple(proto=None, monitor=True, persistence=True,
                       persistence_type=None, persistence_cookie=None,
                       persistence_timeout=None, persistence_granularity=None,
                       sample_pool=1, monitor_ip_port=False,
-                      monitor_proto=None, backup_member=False,
+                      monitor_proto=None, monitor_expected_codes=None,
+                      backup_member=False,
                       disabled_member=False, has_http_reuse=True,
                       pool_cert=False, pool_ca_cert=False, pool_crl=False,
                       tls_enabled=False, hm_host_http_check=False,
@@ -812,7 +814,9 @@ def sample_pool_tuple(proto=None, monitor=True, persistence=True,
                                        enabled=not disabled_member)]
         if monitor is True:
             mon = sample_health_monitor_tuple(
-                proto=monitor_proto, host_http_check=hm_host_http_check)
+                proto=monitor_proto,
+                host_http_check=hm_host_http_check,
+                expected_codes=monitor_expected_codes)
     elif sample_pool == 2:
         id = 'sample_pool_id_2'
         members = [sample_member_tuple('sample_member_id_3', '10.0.0.97',
@@ -820,7 +824,8 @@ def sample_pool_tuple(proto=None, monitor=True, persistence=True,
         if monitor is True:
             mon = sample_health_monitor_tuple(
                 proto=monitor_proto, sample_hm=2,
-                host_http_check=hm_host_http_check)
+                host_http_check=hm_host_http_check,
+                expected_codes=monitor_expected_codes)
 
     return in_pool(
         id=id,
@@ -878,9 +883,9 @@ def sample_session_persistence_tuple(persistence_type=None,
 
 
 def sample_health_monitor_tuple(proto='HTTP', sample_hm=1,
-                                host_http_check=False,
+                                host_http_check=False, expected_codes=None,
                                 provisioning_status=constants.ACTIVE):
-    proto = 'HTTP' if proto is 'TERMINATED_HTTPS' else proto
+    proto = 'HTTP' if proto == 'TERMINATED_HTTPS' else proto
     monitor = collections.namedtuple(
         'monitor', 'id, type, delay, timeout, fall_threshold, rise_threshold,'
                    'http_method, url_path, expected_codes, enabled, '
@@ -910,6 +915,8 @@ def sample_health_monitor_tuple(proto='HTTP', sample_hm=1,
         kwargs.update({'http_version': 1.1, 'domain_name': 'testlab.com'})
     else:
         kwargs.update({'http_version': 1.0, 'domain_name': None})
+    if expected_codes:
+        kwargs.update({'expected_codes': expected_codes})
     if proto == constants.HEALTH_MONITOR_UDP_CONNECT:
         kwargs['check_script_path'] = (CONF.haproxy_amphora.base_path +
                                        'lvs/check/' + 'udp_check.sh')
@@ -928,7 +935,7 @@ def sample_l7policy_tuple(id,
     in_l7policy = collections.namedtuple('l7policy',
                                          'id, action, redirect_pool, '
                                          'redirect_url, redirect_prefix, '
-                                         'l7rules, enabled,'
+                                         'l7rules, enabled, '
                                          'redirect_http_code, '
                                          'provisioning_status')
     l7rules = []
