@@ -11,8 +11,8 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
+from unittest import mock
 
-import mock
 from novaclient import exceptions as nova_exceptions
 from oslo_config import cfg
 from oslo_config import fixture as oslo_fixture
@@ -128,7 +128,7 @@ class TestNovaClient(base.TestCase):
         self.manager.server_groups = mock.MagicMock()
         self.manager._nova_client = mock.MagicMock()
         self.manager.flavor_manager = mock.MagicMock()
-        self.manager.flavor_manager.get = mock.MagicMock()
+        self.manager.availability_zone_manager = mock.MagicMock()
 
         self.nova_response.interface_list.side_effect = [[self.interface_list]]
         self.manager.manager.get.return_value = self.nova_response
@@ -156,6 +156,7 @@ class TestNovaClient(base.TestCase):
         self.compute_id = uuidutils.generate_uuid()
         self.network_id = uuidutils.generate_uuid()
         self.flavor_id = uuidutils.generate_uuid()
+        self.availability_zone = 'my_test_az'
 
         super(TestNovaClient, self).setUp()
 
@@ -218,6 +219,35 @@ class TestNovaClient(base.TestCase):
 
     def test_build_with_availability_zone(self):
         FAKE_AZ = "my_availability_zone"
+
+        amphora_id = self.manager.build(amphora_flavor=1, image_id=1,
+                                        key_name=1,
+                                        sec_groups=1,
+                                        network_ids=[1],
+                                        port_ids=[2],
+                                        user_data='Blah',
+                                        config_drive_files='Files Blah',
+                                        availability_zone=FAKE_AZ)
+
+        self.assertEqual(self.amphora.compute_id, amphora_id)
+
+        self.manager.manager.create.assert_called_with(
+            name="amphora_name",
+            nics=[{'net-id': 1}, {'port-id': 2}],
+            image=1,
+            flavor=1,
+            key_name=1,
+            security_groups=1,
+            files='Files Blah',
+            userdata='Blah',
+            config_drive=True,
+            scheduler_hints=None,
+            availability_zone=FAKE_AZ,
+            block_device_mapping={}
+        )
+
+    def test_build_with_availability_zone_config(self):
+        FAKE_AZ = "my_availability_zone"
         self.conf.config(group="nova", availability_zone=FAKE_AZ)
 
         amphora_id = self.manager.build(amphora_flavor=1, image_id=1,
@@ -506,3 +536,17 @@ class TestNovaClient(base.TestCase):
         self.assertRaises(exceptions.OctaviaException,
                           self.manager.validate_flavor,
                           "bogus")
+
+    def test_validate_availability_zone(self):
+        mock_az = mock.Mock()
+        mock_az.zoneName = self.availability_zone
+        self.manager.availability_zone_manager.list.return_value = [mock_az]
+        self.manager.validate_availability_zone(self.availability_zone)
+        self.manager.availability_zone_manager.list.assert_called_with(
+            detailed=False)
+
+    def test_validate_availability_zone_with_exception(self):
+        self.manager.availability_zone_manager.list.return_value = []
+        self.assertRaises(exceptions.InvalidSubresource,
+                          self.manager.validate_availability_zone,
+                          "bogus")
