@@ -14,11 +14,10 @@
 
 import random
 import time
+from unittest import mock
 
-import mock
 from oslo_config import cfg
 from oslo_utils import uuidutils
-import six
 import sqlalchemy
 
 from octavia.common import constants
@@ -277,21 +276,19 @@ class TestUpdateHealthDb(base.TestCase):
         self.assertTrue(self.amphora_health_repo.replace.called)
 
         # test listener, member
-        for listener_id, listener in six.iteritems(
-                health.get('listeners', {})):
+        for listener_id, listener in health.get('listeners', {}).items():
 
             self.listener_repo.update.assert_any_call(
                 self.session_mock, listener_id,
                 operating_status=constants.ONLINE)
 
-            for pool_id, pool in six.iteritems(listener.get('pools', {})):
+            for pool_id, pool in listener.get('pools', {}).items():
 
                 self.hm.pool_repo.update.assert_any_call(
                     self.session_mock, pool_id,
                     operating_status=constants.ONLINE)
 
-                for member_id, member in six.iteritems(
-                        pool.get('members', {})):
+                for member_id, member in pool.get('members', {}).items():
                     self.member_repo.update.assert_any_call(
                         self.session_mock, member_id,
                         operating_status=constants.ONLINE)
@@ -328,21 +325,19 @@ class TestUpdateHealthDb(base.TestCase):
         self.assertTrue(self.amphora_health_repo.replace.called)
 
         # test listener, member
-        for listener_id, listener in six.iteritems(
-                health.get('listeners', {})):
+        for listener_id, listener in health.get('listeners', {}).items():
 
             self.listener_repo.update.assert_any_call(
                 self.session_mock, listener_id,
                 operating_status=constants.ONLINE)
 
-            for pool_id, pool in six.iteritems(listener.get('pools', {})):
+            for pool_id, pool in listener.get('pools', {}).items():
 
                 self.hm.pool_repo.update.assert_any_call(
                     self.session_mock, pool_id,
                     operating_status=constants.ONLINE)
 
-                for member_id, member in six.iteritems(
-                        pool.get('members', {})):
+                for member_id, member in pool.get('members', {}).items():
                     self.member_repo.update.assert_any_call(
                         self.session_mock, member_id,
                         operating_status=constants.ONLINE)
@@ -365,8 +360,7 @@ class TestUpdateHealthDb(base.TestCase):
         self.assertTrue(self.amphora_health_repo.replace.called)
 
         # test listener, member
-        for listener_id, listener in six.iteritems(
-                health.get('listeners', {})):
+        for listener_id, listener in health.get('listeners', {}).items():
 
             self.listener_repo.update.assert_any_call(
                 self.session_mock, listener_id,
@@ -409,8 +403,7 @@ class TestUpdateHealthDb(base.TestCase):
         self.assertTrue(self.amphora_health_repo.replace.called)
 
         # test listener, member
-        for listener_id, listener in six.iteritems(
-                health.get('listeners')):
+        for listener_id, listener in health.get('listeners').items():
             self.listener_repo.update.assert_any_call(
                 self.session_mock, listener_id,
                 operating_status=constants.ONLINE)
@@ -446,22 +439,20 @@ class TestUpdateHealthDb(base.TestCase):
         self.assertTrue(self.amphora_health_repo.replace.called)
 
         # test listener, member
-        for listener_id, listener in six.iteritems(
-                health.get('listeners', {})):
+        for listener_id, listener in health.get('listeners', {}).items():
 
             self.listener_repo.update.assert_any_call(
                 self.session_mock, listener_id,
                 operating_status=constants.ONLINE)
 
-            for pool_id, pool in six.iteritems(listener.get('pools', {})):
+            for pool_id, pool in listener.get('pools', {}).items():
 
                 # We should not double process a shared pool
                 self.hm.pool_repo.update.assert_called_once_with(
                     self.session_mock, pool_id,
                     operating_status=constants.ONLINE)
 
-                for member_id, member in six.iteritems(
-                        pool.get('members', {})):
+                for member_id, member in pool.get('members', {}).items():
                     self.member_repo.update.assert_any_call(
                         self.session_mock, member_id,
                         operating_status=constants.ONLINE)
@@ -478,7 +469,7 @@ class TestUpdateHealthDb(base.TestCase):
                 "pool-id-1:listener-id-1": {
                     "status": constants.UP,
                     "members": {"member-id-1": constants.UP}},
-                "pool-id-1:listener-id-1": {
+                "pool-id-1:listener-id-2": {
                     "status": constants.UP,
                     "members": {"member-id-1": constants.UP}}},
             "recv_time": time.time()
@@ -490,21 +481,19 @@ class TestUpdateHealthDb(base.TestCase):
         self.assertTrue(self.amphora_health_repo.replace.called)
 
         # test listener, member
-        for listener_id, listener in six.iteritems(
-                health.get('listeners', {})):
+        for listener_id, listener in health.get('listeners', {}).items():
 
             self.listener_repo.update.assert_any_call(
                 self.session_mock, listener_id,
                 operating_status=constants.ONLINE)
 
-        for pool_id, pool in six.iteritems(health.get('pools', {})):
+        for pool_id, pool in health.get('pools', {}).items():
             # We should not double process a shared pool
             self.hm.pool_repo.update.assert_called_once_with(
                 self.session_mock, 'pool-id-1',
                 operating_status=constants.ONLINE)
 
-            for member_id, member in six.iteritems(
-                    pool.get('members', {})):
+            for member_id, member in pool.get('members', {}).items():
                 self.member_repo.update.assert_any_call(
                     self.session_mock, member_id,
                     operating_status=constants.ONLINE)
@@ -535,8 +524,7 @@ class TestUpdateHealthDb(base.TestCase):
         self.assertTrue(self.amphora_health_repo.replace.called)
 
         # test listener, member
-        for listener_id, listener in six.iteritems(
-                health.get('listeners', {})):
+        for listener_id, listener in health.get('listeners', {}).items():
 
             self.listener_repo.update.assert_any_call(
                 self.session_mock, listener_id,
@@ -566,21 +554,19 @@ class TestUpdateHealthDb(base.TestCase):
         self.assertTrue(self.amphora_health_repo.replace.called)
 
         # test listener, member
-        for listener_id, listener in six.iteritems(
-                health.get('listeners', {})):
+        for listener_id, listener in health.get('listeners', {}).items():
 
             self.listener_repo.update.assert_any_call(
                 self.session_mock, listener_id,
                 operating_status=constants.ONLINE)
 
-            for pool_id, pool in six.iteritems(listener.get('pools', {})):
+            for pool_id, pool in listener.get('pools', {}).items():
 
                 self.hm.pool_repo.update.assert_any_call(
                     self.session_mock, pool_id,
                     operating_status=constants.ONLINE)
 
-                for member_id, member in six.iteritems(
-                        pool.get('members', {})):
+                for member_id, member in pool.get('members', {}).items():
 
                     self.member_repo.update.assert_any_call(
                         self.session_mock, member_id,
@@ -606,21 +592,19 @@ class TestUpdateHealthDb(base.TestCase):
         self.assertTrue(self.amphora_health_repo.replace.called)
 
         # test listener, member
-        for listener_id, listener in six.iteritems(
-                health.get('listeners', {})):
+        for listener_id, listener in health.get('listeners', {}).items():
 
             self.listener_repo.update.assert_any_call(
                 self.session_mock, listener_id,
                 operating_status=constants.ONLINE)
 
-            for pool_id, pool in six.iteritems(listener.get('pools', {})):
+            for pool_id, pool in listener.get('pools', {}).items():
 
                 self.hm.pool_repo.update.assert_any_call(
                     self.session_mock, pool_id,
                     operating_status=constants.ONLINE)
 
-                for member_id, member in six.iteritems(
-                        pool.get('members', {})):
+                for member_id, member in pool.get('members', {}).items():
 
                     self.member_repo.update.assert_any_call(
                         self.session_mock, member_id,
@@ -646,14 +630,13 @@ class TestUpdateHealthDb(base.TestCase):
         self.assertTrue(self.amphora_health_repo.replace.called)
 
         # test listener, member
-        for listener_id, listener in six.iteritems(
-                health.get('listeners', {})):
+        for listener_id, listener in health.get('listeners', {}).items():
 
             self.listener_repo.update.assert_any_call(
                 self.session_mock, listener_id,
                 operating_status=constants.ONLINE)
 
-            for pool_id, pool in six.iteritems(listener.get('pools', {})):
+            for pool_id, pool in listener.get('pools', {}).items():
 
                 self.hm.pool_repo.update.assert_any_call(
                     self.session_mock, pool_id,
@@ -683,21 +666,19 @@ class TestUpdateHealthDb(base.TestCase):
         self.assertTrue(self.amphora_health_repo.replace.called)
 
         # test listener, member
-        for listener_id, listener in six.iteritems(
-                health.get('listeners', {})):
+        for listener_id, listener in health.get('listeners', {}).items():
 
             self.listener_repo.update.assert_any_call(
                 self.session_mock, listener_id,
                 operating_status=constants.ONLINE)
 
-            for pool_id, pool in six.iteritems(listener.get('pools', {})):
+            for pool_id, pool in listener.get('pools', {}).items():
 
                 self.hm.pool_repo.update.assert_any_call(
                     self.session_mock, pool_id,
                     operating_status=constants.DEGRADED)
 
-                for member_id, member in six.iteritems(
-                        pool.get('members', {})):
+                for member_id, member in pool.get('members', {}).items():
 
                     self.member_repo.update.assert_any_call(
                         self.session_mock, member_id,
@@ -726,14 +707,13 @@ class TestUpdateHealthDb(base.TestCase):
         self.assertTrue(self.amphora_health_repo.replace.called)
 
         # test listener, member
-        for listener_id, listener in six.iteritems(
-                health.get('listeners', {})):
+        for listener_id, listener in health.get('listeners', {}).items():
 
             self.listener_repo.update.assert_any_call(
                 self.session_mock, listener_id,
                 operating_status=constants.ONLINE)
 
-            for pool_id, pool in six.iteritems(listener.get('pools', {})):
+            for pool_id, pool in listener.get('pools', {}).items():
 
                 self.hm.pool_repo.update.assert_any_call(
                     self.session_mock, pool_id,
@@ -767,14 +747,13 @@ class TestUpdateHealthDb(base.TestCase):
         self.assertTrue(self.amphora_health_repo.replace.called)
 
         # test listener, member
-        for listener_id, listener in six.iteritems(
-                health.get('listeners', {})):
+        for listener_id, listener in health.get('listeners', {}).items():
 
             self.listener_repo.update.assert_any_call(
                 self.session_mock, listener_id,
                 operating_status=constants.ONLINE)
 
-            for pool_id, pool in six.iteritems(listener.get('pools', {})):
+            for pool_id, pool in listener.get('pools', {}).items():
 
                 self.hm.pool_repo.update.assert_any_call(
                     self.session_mock, pool_id,
@@ -807,21 +786,19 @@ class TestUpdateHealthDb(base.TestCase):
         self.assertTrue(self.amphora_health_repo.replace.called)
 
         # test listener, member
-        for listener_id, listener in six.iteritems(
-                health.get('listeners', {})):
+        for listener_id, listener in health.get('listeners', {}).items():
 
             self.listener_repo.update.assert_any_call(
                 self.session_mock, listener_id,
                 operating_status=constants.ONLINE)
 
-            for pool_id, pool in six.iteritems(listener.get('pools', {})):
+            for pool_id, pool in listener.get('pools', {}).items():
 
                 self.hm.pool_repo.update.assert_any_call(
                     self.session_mock, pool_id,
                     operating_status=constants.ONLINE)
 
-                for member_id, member in six.iteritems(
-                        pool.get('members', {})):
+                for member_id, member in pool.get('members', {}).items():
 
                     self.member_repo.update.assert_any_call(
                         self.session_mock, member_id,
@@ -850,21 +827,19 @@ class TestUpdateHealthDb(base.TestCase):
         self.assertTrue(self.amphora_repo.get_lb_for_health_update.called)
 
         # test listener, member
-        for listener_id, listener in six.iteritems(
-                health.get('listeners', {})):
+        for listener_id, listener in health.get('listeners', {}).items():
 
             self.listener_repo.update.assert_any_call(
                 self.session_mock, listener_id,
                 operating_status=constants.ONLINE)
 
-            for pool_id, pool in six.iteritems(listener.get('pools', {})):
+            for pool_id, pool in listener.get('pools', {}).items():
 
                 self.hm.pool_repo.update.assert_any_call(
                     self.session_mock, pool_id,
                     operating_status=constants.ONLINE)
 
-                for member_id, member in six.iteritems(
-                        pool.get('members', {})):
+                for member_id, member in pool.get('members', {}).items():
 
                     self.member_repo.update.assert_any_call(
                         self.session_mock, member_id,
@@ -895,21 +870,19 @@ class TestUpdateHealthDb(base.TestCase):
         self.assertTrue(self.amphora_health_repo.replace.called)
 
         # test listener, member
-        for listener_id, listener in six.iteritems(
-                health.get('listeners', {})):
+        for listener_id, listener in health.get('listeners', {}).items():
 
             self.listener_repo.update.assert_any_call(
                 self.session_mock, listener_id,
                 operating_status=constants.DEGRADED)
 
-            for pool_id, pool in six.iteritems(listener.get('pools', {})):
+            for pool_id, pool in listener.get('pools', {}).items():
 
                 self.hm.pool_repo.update.assert_any_call(
                     self.session_mock, pool_id,
                     operating_status=constants.DEGRADED)
 
-                for member_id, member in six.iteritems(
-                        pool.get('members', {})):
+                for member_id, member in pool.get('members', {}).items():
 
                     self.member_repo.update.assert_any_call(
                         self.session_mock, member_id,
@@ -946,21 +919,19 @@ class TestUpdateHealthDb(base.TestCase):
         self.assertTrue(self.amphora_health_repo.replace.called)
 
         # test listener, member
-        for listener_id, listener in six.iteritems(
-                health.get('listeners', {})):
+        for listener_id, listener in health.get('listeners', {}).items():
 
             self.listener_repo.update.assert_any_call(
                 self.session_mock, listener_id,
                 operating_status=constants.ONLINE)
 
-            for pool_id, pool in six.iteritems(listener.get('pools', {})):
+            for pool_id, pool in listener.get('pools', {}).items():
 
                 self.hm.pool_repo.update.assert_any_call(
                     self.session_mock, pool_id,
                     operating_status=constants.ERROR)
 
-                for member_id, member in six.iteritems(
-                        pool.get('members', {})):
+                for member_id, member in pool.get('members', {}).items():
 
                     self.member_repo.update.assert_any_call(
                         self.session_mock, member_id,
@@ -1093,21 +1064,19 @@ class TestUpdateHealthDb(base.TestCase):
         self.assertTrue(self.amphora_health_repo.replace.called)
 
         # test listener, member
-        for listener_id, listener in six.iteritems(
-                health.get('listeners', {})):
+        for listener_id, listener in health.get('listeners', {}).items():
 
             self.listener_repo.update.assert_any_call(
                 self.session_mock, listener_id,
                 operating_status=constants.ONLINE)
 
-            for pool_id, pool in six.iteritems(listener.get('pools', {})):
+            for pool_id, pool in listener.get('pools', {}).items():
 
                 self.hm.pool_repo.update.assert_any_call(
                     self.session_mock, pool_id,
                     operating_status=constants.ONLINE)
 
-                for member_id, member in six.iteritems(
-                        pool.get('members', {})):
+                for member_id, member in pool.get('members', {}).items():
 
                     self.member_repo.update.assert_any_call(
                         self.session_mock, member_id,
