@@ -12,8 +12,8 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 #
+from unittest import mock
 
-import mock
 from oslo_config import cfg
 from oslo_config import fixture as oslo_fixture
 from oslo_utils import uuidutils
@@ -59,7 +59,7 @@ class TestAmphoraFlows(base.TestCase):
         self.assertIn(constants.SERVER_PEM, amp_flow.provides)
 
         self.assertEqual(5, len(amp_flow.provides))
-        self.assertEqual(3, len(amp_flow.requires))
+        self.assertEqual(4, len(amp_flow.requires))
 
     def test_get_create_amphora_flow_cert(self, mock_get_net_driver):
         self.AmpFlow = amphora_flows.AmphoraFlows()
@@ -73,7 +73,7 @@ class TestAmphoraFlows(base.TestCase):
         self.assertIn(constants.COMPUTE_ID, amp_flow.provides)
 
         self.assertEqual(5, len(amp_flow.provides))
-        self.assertEqual(3, len(amp_flow.requires))
+        self.assertEqual(4, len(amp_flow.requires))
 
     def test_get_create_amphora_for_lb_flow(self, mock_get_net_driver):
 
@@ -91,7 +91,7 @@ class TestAmphoraFlows(base.TestCase):
         self.assertIn(constants.SERVER_PEM, amp_flow.provides)
 
         self.assertEqual(5, len(amp_flow.provides))
-        self.assertEqual(4, len(amp_flow.requires))
+        self.assertEqual(5, len(amp_flow.requires))
 
     def test_get_cert_create_amphora_for_lb_flow(self, mock_get_net_driver):
 
@@ -111,7 +111,7 @@ class TestAmphoraFlows(base.TestCase):
         self.assertIn(constants.SERVER_PEM, amp_flow.provides)
 
         self.assertEqual(5, len(amp_flow.provides))
-        self.assertEqual(4, len(amp_flow.requires))
+        self.assertEqual(5, len(amp_flow.requires))
 
     def test_get_cert_master_create_amphora_for_lb_flow(
             self, mock_get_net_driver):
@@ -132,7 +132,7 @@ class TestAmphoraFlows(base.TestCase):
         self.assertIn(constants.SERVER_PEM, amp_flow.provides)
 
         self.assertEqual(5, len(amp_flow.provides))
-        self.assertEqual(4, len(amp_flow.requires))
+        self.assertEqual(5, len(amp_flow.requires))
 
     def test_get_cert_master_rest_anti_affinity_create_amphora_for_lb_flow(
             self, mock_get_net_driver):
@@ -150,7 +150,7 @@ class TestAmphoraFlows(base.TestCase):
         self.assertIn(constants.SERVER_PEM, amp_flow.provides)
 
         self.assertEqual(5, len(amp_flow.provides))
-        self.assertEqual(4, len(amp_flow.requires))
+        self.assertEqual(5, len(amp_flow.requires))
         self.conf.config(group="nova", enable_anti_affinity=False)
 
     def test_get_cert_backup_create_amphora_for_lb_flow(
@@ -171,7 +171,7 @@ class TestAmphoraFlows(base.TestCase):
         self.assertIn(constants.SERVER_PEM, amp_flow.provides)
 
         self.assertEqual(5, len(amp_flow.provides))
-        self.assertEqual(4, len(amp_flow.requires))
+        self.assertEqual(5, len(amp_flow.requires))
 
     def test_get_cert_bogus_create_amphora_for_lb_flow(
             self, mock_get_net_driver):
@@ -191,7 +191,7 @@ class TestAmphoraFlows(base.TestCase):
         self.assertIn(constants.SERVER_PEM, amp_flow.provides)
 
         self.assertEqual(5, len(amp_flow.provides))
-        self.assertEqual(4, len(amp_flow.requires))
+        self.assertEqual(5, len(amp_flow.requires))
 
     def test_get_cert_backup_rest_anti_affinity_create_amphora_for_lb_flow(
             self, mock_get_net_driver):
@@ -208,7 +208,7 @@ class TestAmphoraFlows(base.TestCase):
         self.assertIn(constants.SERVER_PEM, amp_flow.provides)
 
         self.assertEqual(5, len(amp_flow.provides))
-        self.assertEqual(4, len(amp_flow.requires))
+        self.assertEqual(5, len(amp_flow.requires))
         self.conf.config(group="nova", enable_anti_affinity=False)
 
     def test_get_delete_amphora_flow(self, mock_get_net_driver):
@@ -249,6 +249,7 @@ class TestAmphoraFlows(base.TestCase):
 
         self.assertIsInstance(amp_flow, flow.Flow)
 
+        self.assertIn(constants.AVAILABILITY_ZONE, amp_flow.requires)
         self.assertIn(constants.BUILD_TYPE_PRIORITY, amp_flow.requires)
         self.assertIn(constants.FLAVOR, amp_flow.requires)
         self.assertIn(constants.LOADBALANCER, amp_flow.requires)
@@ -269,7 +270,7 @@ class TestAmphoraFlows(base.TestCase):
         self.assertIn(constants.SERVER_PEM, amp_flow.provides)
         self.assertIn(constants.VIP_SG_ID, amp_flow.provides)
 
-        self.assertEqual(6, len(amp_flow.requires))
+        self.assertEqual(7, len(amp_flow.requires))
         self.assertEqual(13, len(amp_flow.provides))
 
     def test_get_failover_flow_standalone(self, mock_get_net_driver):
@@ -282,6 +283,7 @@ class TestAmphoraFlows(base.TestCase):
 
         self.assertIsInstance(amp_flow, flow.Flow)
 
+        self.assertIn(constants.AVAILABILITY_ZONE, amp_flow.requires)
         self.assertIn(constants.BUILD_TYPE_PRIORITY, amp_flow.requires)
         self.assertIn(constants.FLAVOR, amp_flow.requires)
         self.assertIn(constants.LOADBALANCER, amp_flow.requires)
@@ -301,7 +303,7 @@ class TestAmphoraFlows(base.TestCase):
         self.assertIn(constants.SERVER_PEM, amp_flow.provides)
         self.assertIn(constants.VIP_SG_ID, amp_flow.provides)
 
-        self.assertEqual(6, len(amp_flow.requires))
+        self.assertEqual(7, len(amp_flow.requires))
         self.assertEqual(12, len(amp_flow.provides))
 
     def test_get_failover_flow_bogus_role(self, mock_get_net_driver):
@@ -313,20 +315,9 @@ class TestAmphoraFlows(base.TestCase):
 
         self.assertIsInstance(amp_flow, flow.Flow)
 
-        # TODO(johnsom) Uncomment after amphora failover builds a replacement
-        #               amphora.
-        # self.assertIn(constants.BUILD_TYPE_PRIORITY, amp_flow.requires)
-        # self.assertIn(constants.FLAVOR, amp_flow.requires)
-        # self.assertEqual(5, len(amp_flow.requires))
         self.assertIn(constants.LOADBALANCER_ID, amp_flow.requires)
 
-        # self.assertIn(constants.AMPHORA, amp_flow.provides)
-        # self.assertIn(constants.AMPHORA_ID, amp_flow.provides)
-        # self.assertIn(constants.COMPUTE_ID, amp_flow.provides)
-        # self.assertIn(constants.COMPUTE_OBJ, amp_flow.provides)
-        # self.assertIn(constants.SERVER_PEM, amp_flow.provides)
-        # self.assertIn(constants.VIP_SG_ID, amp_flow.provides)
-        # self.assertEqual(6, len(amp_flow.provides))
+        self.assertIn(constants.VIP_SG_ID, amp_flow.provides)
 
         self.assertEqual(1, len(amp_flow.requires))
         self.assertEqual(1, len(amp_flow.provides))
@@ -337,13 +328,10 @@ class TestAmphoraFlows(base.TestCase):
 
         self.assertIsInstance(amp_flow, flow.Flow)
 
-        # TODO(johnsom) Uncomment after amphora failover builds a replacement
-        #               amphora.
-        # self.assertIn(constants.BUILD_TYPE_PRIORITY, amp_flow.requires)
-        # self.assertEqual(5, len(amp_flow.requires))
-        # self.assertEqual(6, len(amp_flow.provides))
         self.assertIn(constants.LOADBALANCER_ID, amp_flow.requires)
 
+        self.assertIn(constants.VIP_SG_ID, amp_flow.provides)
+
         self.assertEqual(1, len(amp_flow.requires))
         self.assertEqual(1, len(amp_flow.provides))
 
@@ -464,6 +452,7 @@ class TestAmphoraFlows(base.TestCase):
 
         self.assertIsInstance(get_amp_flow, flow.Flow)
 
+        self.assertIn(constants.AVAILABILITY_ZONE, get_amp_flow.requires)
         self.assertIn(constants.BUILD_TYPE_PRIORITY, get_amp_flow.requires)
         self.assertIn(constants.FLAVOR, get_amp_flow.requires)
         self.assertIn(constants.LOADBALANCER, get_amp_flow.requires)
@@ -481,7 +470,7 @@ class TestAmphoraFlows(base.TestCase):
         self.assertIn(constants.DELTA, get_amp_flow.provides)
         self.assertIn(constants.SERVER_PEM, get_amp_flow.provides)
 
-        self.assertEqual(7, len(get_amp_flow.requires), get_amp_flow.requires)
+        self.assertEqual(8, len(get_amp_flow.requires), get_amp_flow.requires)
         self.assertEqual(9, len(get_amp_flow.provides), get_amp_flow.provides)
 
     def test_get_amphora_for_lb_failover_flow_act_stdby(self,
@@ -494,6 +483,7 @@ class TestAmphoraFlows(base.TestCase):
 
         self.assertIsInstance(get_amp_flow, flow.Flow)
 
+        self.assertIn(constants.AVAILABILITY_ZONE, get_amp_flow.requires)
         self.assertIn(constants.BUILD_TYPE_PRIORITY, get_amp_flow.requires)
         self.assertIn(constants.FLAVOR, get_amp_flow.requires)
         self.assertIn(constants.LOADBALANCER, get_amp_flow.requires)
@@ -511,5 +501,5 @@ class TestAmphoraFlows(base.TestCase):
         self.assertIn(constants.DELTA, get_amp_flow.provides)
         self.assertIn(constants.SERVER_PEM, get_amp_flow.provides)
 
-        self.assertEqual(7, len(get_amp_flow.requires), get_amp_flow.requires)
+        self.assertEqual(8, len(get_amp_flow.requires), get_amp_flow.requires)
         self.assertEqual(9, len(get_amp_flow.provides), get_amp_flow.provides)
