@@ -12,8 +12,8 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 #
+from unittest import mock
 
-import mock
 from oslo_config import cfg
 from oslo_config import fixture as oslo_fixture
 from oslo_utils import uuidutils
@@ -196,7 +196,7 @@ class TestLoadBalancerFlows(base.TestCase):
         self.assertIn(constants.AMP_DATA, create_flow.provides)
         self.assertIn(constants.AMPHORA_NETWORK_CONFIG, create_flow.provides)
 
-        self.assertEqual(5, len(create_flow.requires))
+        self.assertEqual(6, len(create_flow.requires))
         self.assertEqual(13, len(create_flow.provides),
                          create_flow.provides)
 
@@ -224,7 +224,7 @@ class TestLoadBalancerFlows(base.TestCase):
         self.assertIn(constants.AMPHORAE_NETWORK_CONFIG,
                       create_flow.provides)
 
-        self.assertEqual(5, len(create_flow.requires))
+        self.assertEqual(6, len(create_flow.requires))
         self.assertEqual(16, len(create_flow.provides),
                          create_flow.provides)
 
@@ -237,6 +237,7 @@ class TestLoadBalancerFlows(base.TestCase):
 
         self.assertIsInstance(failover_flow, flow.Flow)
 
+        self.assertIn(constants.AVAILABILITY_ZONE, failover_flow.requires)
         self.assertIn(constants.BUILD_TYPE_PRIORITY, failover_flow.requires)
         self.assertIn(constants.FLAVOR, failover_flow.requires)
         self.assertIn(constants.LOADBALANCER, failover_flow.requires)
@@ -256,7 +257,7 @@ class TestLoadBalancerFlows(base.TestCase):
         self.assertIn(constants.VIP, failover_flow.provides)
         self.assertIn(constants.VIP_SG_ID, failover_flow.provides)
 
-        self.assertEqual(5, len(failover_flow.requires),
+        self.assertEqual(6, len(failover_flow.requires),
                          failover_flow.requires)
         self.assertEqual(12, len(failover_flow.provides),
                          failover_flow.provides)
@@ -316,6 +317,7 @@ class TestLoadBalancerFlows(base.TestCase):
 
         self.assertIsInstance(failover_flow, flow.Flow)
 
+        self.assertIn(constants.AVAILABILITY_ZONE, failover_flow.requires)
         self.assertIn(constants.BUILD_TYPE_PRIORITY, failover_flow.requires)
         self.assertIn(constants.FLAVOR, failover_flow.requires)
         self.assertIn(constants.LOADBALANCER, failover_flow.requires)
@@ -341,7 +343,7 @@ class TestLoadBalancerFlows(base.TestCase):
         self.assertIn(constants.VIP, failover_flow.provides)
         self.assertIn(constants.VIP_SG_ID, failover_flow.provides)
 
-        self.assertEqual(5, len(failover_flow.requires),
+        self.assertEqual(6, len(failover_flow.requires),
                          failover_flow.requires)
         self.assertEqual(16, len(failover_flow.provides),
                          failover_flow.provides)
