@@ -12,9 +12,9 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 #
+from unittest import mock
 
 from cryptography import fernet
-import mock
 from oslo_config import cfg
 from oslo_config import fixture as oslo_fixture
 from oslo_utils import uuidutils
@@ -125,7 +125,8 @@ class TestComputeTasks(base.TestCase):
                                 'amphora-agent.conf': 'test_conf',
                                 '/etc/rsyslog.d/10-rsyslog.conf': 'FAKE CFG'},
             user_data=None,
-            server_group_id=SERVER_GRPOUP_ID)
+            server_group_id=SERVER_GRPOUP_ID,
+            availability_zone=None)
 
         # Make sure it returns the expected compute_id
         self.assertEqual(COMPUTE_ID, compute_id)
@@ -186,7 +187,77 @@ class TestComputeTasks(base.TestCase):
             port_ids=[PORT_ID],
             config_drive_files=None,
             user_data='test_ud_conf',
-            server_group_id=None)
+            server_group_id=None,
+            availability_zone=None)
+
+        # Make sure it returns the expected compute_id
+        self.assertEqual(COMPUTE_ID, compute_id)
+
+        # Test that a build exception is raised
+        createcompute = compute_tasks.ComputeCreate()
+
+        self.assertRaises(TypeError,
+                          createcompute.execute,
+                          _amphora_mock, config_drive_files='test_cert')
+
+        # Test revert()
+
+        _amphora_mock.compute_id = COMPUTE_ID
+
+        createcompute = compute_tasks.ComputeCreate()
+        createcompute.revert(compute_id, _amphora_mock.id)
+
+        # Validate that the delete method was called properly
+        mock_driver.delete.assert_called_once_with(
+            COMPUTE_ID)
+
+        # Test that a delete exception is not raised
+
+        createcompute.revert(COMPUTE_ID, _amphora_mock.id)
+
+    @mock.patch('octavia.common.jinja.logging.logging_jinja_cfg.'
+                'LoggingJinjaTemplater.build_logging_config')
+    @mock.patch('jinja2.Environment.get_template')
+    @mock.patch('octavia.amphorae.backends.agent.'
+                'agent_jinja_cfg.AgentJinjaTemplater.'
+                'build_agent_config', return_value='test_conf')
+    @mock.patch('stevedore.driver.DriverManager.driver')
+    def test_compute_create_availability_zone(self, mock_driver, mock_conf,
+                                              mock_jinja, mock_log_cfg):
+
+        image_owner_id = uuidutils.generate_uuid()
+        compute_zone = uuidutils.generate_uuid()
+        az_dict = {constants.COMPUTE_ZONE: compute_zone}
+
+        self.conf.config(
+            group="controller_worker", amp_image_owner_id=image_owner_id)
+        mock_log_cfg.return_value = 'FAKE CFG'
+
+        createcompute = compute_tasks.ComputeCreate()
+
+        mock_driver.build.return_value = COMPUTE_ID
+        # Test execute()
+        compute_id = createcompute.execute(_amphora_mock.id, ports=[_port],
+                                           server_group_id=SERVER_GRPOUP_ID,
+                                           availability_zone=az_dict)
+
+        # Validate that the build method was called properly
+        mock_driver.build.assert_called_once_with(
+            name="amphora-" + _amphora_mock.id,
+            amphora_flavor=AMP_FLAVOR_ID,
+            image_id=AMP_IMAGE_ID,
+            image_tag=AMP_IMAGE_TAG,
+            image_owner=image_owner_id,
+            key_name=AMP_SSH_KEY_NAME,
+            sec_groups=AMP_SEC_GROUPS,
+            network_ids=AMP_NET,
+            port_ids=[PORT_ID],
+            config_drive_files={'/etc/octavia/'
+                                'amphora-agent.conf': 'test_conf',
+                                '/etc/rsyslog.d/10-rsyslog.conf': 'FAKE CFG'},
+            user_data=None,
+            server_group_id=SERVER_GRPOUP_ID,
+            availability_zone=compute_zone)
 
         # Make sure it returns the expected compute_id
         self.assertEqual(COMPUTE_ID, compute_id)
@@ -251,7 +322,8 @@ class TestComputeTasks(base.TestCase):
                                 'amphora-agent.conf': 'test_conf',
                                 '/etc/rsyslog.d/10-rsyslog.conf': 'FAKE CFG'},
             user_data=None,
-            server_group_id=SERVER_GRPOUP_ID)
+            server_group_id=SERVER_GRPOUP_ID,
+            availability_zone=None)
 
         self.assertEqual(COMPUTE_ID, compute_id)
 
@@ -287,7 +359,7 @@ class TestComputeTasks(base.TestCase):
     def test_compute_create_cert(self, mock_driver, mock_conf, mock_jinja,
                                  mock_log_cfg):
         createcompute = compute_tasks.CertComputeCreate()
-        key = utils.get_six_compatible_server_certs_key_passphrase()
+        key = utils.get_compatible_server_certs_key_passphrase()
         fer = fernet.Fernet(key)
         mock_log_cfg.return_value = 'FAKE CFG'
 
@@ -296,7 +368,7 @@ class TestComputeTasks(base.TestCase):
         self.useFixture(test_utils.OpenFixture(path, 'test'))
         # Test execute()
         test_cert = fer.encrypt(
-            utils.get_six_compatible_value('test_cert')
+            utils.get_compatible_value('test_cert')
         )
         compute_id = createcompute.execute(_amphora_mock.id, test_cert,
                                            server_group_id=SERVER_GRPOUP_ID
@@ -319,7 +391,8 @@ class TestComputeTasks(base.TestCase):
                 '/etc/octavia/certs/server.pem': fer.decrypt(test_cert),
                 '/etc/octavia/certs/client_ca.pem': 'test',
                 '/etc/octavia/amphora-agent.conf': 'test_conf'},
-            server_group_id=SERVER_GRPOUP_ID)
+            server_group_id=SERVER_GRPOUP_ID,
+            availability_zone=None)
 
         self.assertEqual(COMPUTE_ID, compute_id)
 
@@ -363,15 +436,23 @@ class TestComputeTasks(base.TestCase):
         mock_driver.get_amphora.return_value = _amphora_mock, None
 
         computewait = compute_tasks.ComputeActiveWait()
-        computewait.execute(COMPUTE_ID, AMPHORA_ID)
 
-        mock_driver.get_amphora.assert_called_once_with(COMPUTE_ID)
+        # Test with no AZ
+        computewait.execute(COMPUTE_ID, AMPHORA_ID, None)
+        mock_driver.get_amphora.assert_called_once_with(COMPUTE_ID, None)
 
+        # Test with AZ
+        mock_driver.reset_mock()
+        az = {constants.MANAGEMENT_NETWORK: uuidutils.generate_uuid()}
+        computewait.execute(COMPUTE_ID, AMPHORA_ID, az)
+        mock_driver.get_amphora.assert_called_once_with(
+            COMPUTE_ID, az[constants.MANAGEMENT_NETWORK])
+
+        # Test with deleted amp
         _amphora_mock.status = constants.DELETED
-
         self.assertRaises(exceptions.ComputeWaitTimeoutException,
                           computewait.execute,
-                          _amphora_mock, AMPHORA_ID)
+                          _amphora_mock, AMPHORA_ID, None)
 
     @mock.patch('octavia.controller.worker.amphora_rate_limit'
                 '.AmphoraBuildRateLimit.remove_from_build_req_queue')
@@ -390,15 +471,15 @@ class TestComputeTasks(base.TestCase):
         mock_driver.get_amphora.return_value = _amphora_mock, None
 
         computewait = compute_tasks.ComputeActiveWait()
-        computewait.execute(COMPUTE_ID, AMPHORA_ID)
+        computewait.execute(COMPUTE_ID, AMPHORA_ID, None)
 
-        mock_driver.get_amphora.assert_called_once_with(COMPUTE_ID)
+        mock_driver.get_amphora.assert_called_once_with(COMPUTE_ID, None)
 
         _amphora_mock.status = constants.ERROR
 
         self.assertRaises(exceptions.ComputeBuildException,
                           computewait.execute,
-                          _amphora_mock, AMPHORA_ID)
+                          _amphora_mock, AMPHORA_ID, None)
 
     @mock.patch('octavia.controller.worker.amphora_rate_limit'
                 '.AmphoraBuildRateLimit.remove_from_build_req_queue')
@@ -415,9 +496,9 @@ class TestComputeTasks(base.TestCase):
         mock_driver.get_amphora.return_value = _amphora_mock, None
 
         computewait = compute_tasks.ComputeActiveWait()
-        computewait.execute(COMPUTE_ID, AMPHORA_ID)
+        computewait.execute(COMPUTE_ID, AMPHORA_ID, None)
 
-        mock_driver.get_amphora.assert_called_once_with(COMPUTE_ID)
+        mock_driver.get_amphora.assert_called_once_with(COMPUTE_ID, None)
         mock_remove_from_build_queue.assert_not_called()
 
     @mock.patch('stevedore.driver.DriverManager.driver')
