@@ -12,10 +12,11 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 #
+from unittest import mock
 
-import mock
 from oslo_config import cfg
 from oslo_config import fixture as oslo_fixture
+from oslo_utils import uuidutils
 from taskflow.patterns import linear_flow as flow
 
 from octavia.common import constants
@@ -42,6 +43,7 @@ class TestAmphoraFlows(base.TestCase):
         self.amp1 = data_models.Amphora(id=1)
         self.amp2 = data_models.Amphora(id=2)
         self.amp3 = data_models.Amphora(id=3, status=constants.DELETED)
+        self.amp4 = data_models.Amphora(id=uuidutils.generate_uuid())
         self.lb = data_models.LoadBalancer(
             id=4, amphorae=[self.amp1, self.amp2, self.amp3])
 
@@ -54,10 +56,15 @@ class TestAmphoraFlows(base.TestCase):
         self.assertIn(constants.AMPHORA, amp_flow.provides)
         self.assertIn(constants.AMPHORA_ID, amp_flow.provides)
         self.assertIn(constants.COMPUTE_ID, amp_flow.provides)
+        self.assertIn(constants.COMPUTE_OBJ, amp_flow.provides)
         self.assertIn(constants.SERVER_PEM, amp_flow.provides)
 
+        self.assertIn(constants.BUILD_TYPE_PRIORITY, amp_flow.requires)
+        self.assertIn(constants.FLAVOR, amp_flow.requires)
+        self.assertIn(constants.AVAILABILITY_ZONE, amp_flow.requires)
+
         self.assertEqual(5, len(amp_flow.provides))
-        self.assertEqual(2, len(amp_flow.requires))
+        self.assertEqual(4, len(amp_flow.requires))
 
     def test_get_create_amphora_flow_cert(self, mock_get_net_driver):
         self.AmpFlow = amphora_flows.AmphoraFlows()
@@ -69,9 +76,15 @@ class TestAmphoraFlows(base.TestCase):
         self.assertIn(constants.AMPHORA, amp_flow.provides)
         self.assertIn(constants.AMPHORA_ID, amp_flow.provides)
         self.assertIn(constants.COMPUTE_ID, amp_flow.provides)
+        self.assertIn(constants.COMPUTE_OBJ, amp_flow.provides)
+        self.assertIn(constants.SERVER_PEM, amp_flow.provides)
+
+        self.assertIn(constants.BUILD_TYPE_PRIORITY, amp_flow.requires)
+        self.assertIn(constants.FLAVOR, amp_flow.requires)
+        self.assertIn(constants.AVAILABILITY_ZONE, amp_flow.requires)
 
         self.assertEqual(5, len(amp_flow.provides))
-        self.assertEqual(2, len(amp_flow.requires))
+        self.assertEqual(4, len(amp_flow.requires))
 
     def test_get_create_amphora_for_lb_flow(self, mock_get_net_driver):
 
@@ -81,6 +94,7 @@ class TestAmphoraFlows(base.TestCase):
         self.assertIsInstance(amp_flow, flow.Flow)
 
         self.assertIn(constants.FLAVOR, amp_flow.requires)
+        self.assertIn(constants.AVAILABILITY_ZONE, amp_flow.requires)
         self.assertIn(constants.BUILD_TYPE_PRIORITY, amp_flow.requires)
         self.assertIn(constants.LOADBALANCER_ID, amp_flow.requires)
 
@@ -91,7 +105,7 @@ class TestAmphoraFlows(base.TestCase):
         self.assertIn(constants.SERVER_PEM, amp_flow.provides)
 
         self.assertEqual(5, len(amp_flow.provides))
-        self.assertEqual(3, len(amp_flow.requires))
+        self.assertEqual(5, len(amp_flow.requires))
 
     def test_get_cert_create_amphora_for_lb_flow(self, mock_get_net_driver):
 
@@ -103,6 +117,7 @@ class TestAmphoraFlows(base.TestCase):
         self.assertIsInstance(amp_flow, flow.Flow)
 
         self.assertIn(constants.FLAVOR, amp_flow.requires)
+        self.assertIn(constants.AVAILABILITY_ZONE, amp_flow.requires)
         self.assertIn(constants.BUILD_TYPE_PRIORITY, amp_flow.requires)
         self.assertIn(constants.LOADBALANCER_ID, amp_flow.requires)
 
@@ -113,7 +128,7 @@ class TestAmphoraFlows(base.TestCase):
         self.assertIn(constants.SERVER_PEM, amp_flow.provides)
 
         self.assertEqual(5, len(amp_flow.provides))
-        self.assertEqual(3, len(amp_flow.requires))
+        self.assertEqual(5, len(amp_flow.requires))
 
     def test_get_cert_master_create_amphora_for_lb_flow(
             self, mock_get_net_driver):
@@ -126,6 +141,7 @@ class TestAmphoraFlows(base.TestCase):
         self.assertIsInstance(amp_flow, flow.Flow)
 
         self.assertIn(constants.FLAVOR, amp_flow.requires)
+        self.assertIn(constants.AVAILABILITY_ZONE, amp_flow.requires)
         self.assertIn(constants.BUILD_TYPE_PRIORITY, amp_flow.requires)
         self.assertIn(constants.LOADBALANCER_ID, amp_flow.requires)
 
@@ -136,7 +152,7 @@ class TestAmphoraFlows(base.TestCase):
         self.assertIn(constants.SERVER_PEM, amp_flow.provides)
 
         self.assertEqual(5, len(amp_flow.provides))
-        self.assertEqual(3, len(amp_flow.requires))
+        self.assertEqual(5, len(amp_flow.requires))
 
     def test_get_cert_master_rest_anti_affinity_create_amphora_for_lb_flow(
             self, mock_get_net_driver):
@@ -150,6 +166,7 @@ class TestAmphoraFlows(base.TestCase):
         self.assertIsInstance(amp_flow, flow.Flow)
 
         self.assertIn(constants.FLAVOR, amp_flow.requires)
+        self.assertIn(constants.AVAILABILITY_ZONE, amp_flow.requires)
         self.assertIn(constants.BUILD_TYPE_PRIORITY, amp_flow.requires)
         self.assertIn(constants.LOADBALANCER_ID, amp_flow.requires)
         self.assertIn(constants.SERVER_GROUP_ID, amp_flow.requires)
@@ -161,7 +178,7 @@ class TestAmphoraFlows(base.TestCase):
         self.assertIn(constants.SERVER_PEM, amp_flow.provides)
 
         self.assertEqual(5, len(amp_flow.provides))
-        self.assertEqual(4, len(amp_flow.requires))
+        self.assertEqual(5, len(amp_flow.requires))
         self.conf.config(group="nova", enable_anti_affinity=False)
 
     def test_get_cert_backup_create_amphora_for_lb_flow(
@@ -174,6 +191,7 @@ class TestAmphoraFlows(base.TestCase):
         self.assertIsInstance(amp_flow, flow.Flow)
 
         self.assertIn(constants.FLAVOR, amp_flow.requires)
+        self.assertIn(constants.AVAILABILITY_ZONE, amp_flow.requires)
         self.assertIn(constants.BUILD_TYPE_PRIORITY, amp_flow.requires)
         self.assertIn(constants.LOADBALANCER_ID, amp_flow.requires)
 
@@ -184,7 +202,7 @@ class TestAmphoraFlows(base.TestCase):
         self.assertIn(constants.SERVER_PEM, amp_flow.provides)
 
         self.assertEqual(5, len(amp_flow.provides))
-        self.assertEqual(3, len(amp_flow.requires))
+        self.assertEqual(5, len(amp_flow.requires))
 
     def test_get_cert_bogus_create_amphora_for_lb_flow(
             self, mock_get_net_driver):
@@ -196,6 +214,7 @@ class TestAmphoraFlows(base.TestCase):
         self.assertIsInstance(amp_flow, flow.Flow)
 
         self.assertIn(constants.FLAVOR, amp_flow.requires)
+        self.assertIn(constants.AVAILABILITY_ZONE, amp_flow.requires)
         self.assertIn(constants.BUILD_TYPE_PRIORITY, amp_flow.requires)
         self.assertIn(constants.LOADBALANCER_ID, amp_flow.requires)
 
@@ -206,7 +225,7 @@ class TestAmphoraFlows(base.TestCase):
         self.assertIn(constants.SERVER_PEM, amp_flow.provides)
 
         self.assertEqual(5, len(amp_flow.provides))
-        self.assertEqual(3, len(amp_flow.requires))
+        self.assertEqual(5, len(amp_flow.requires))
 
     def test_get_cert_backup_rest_anti_affinity_create_amphora_for_lb_flow(
             self, mock_get_net_driver):
@@ -219,6 +238,7 @@ class TestAmphoraFlows(base.TestCase):
         self.assertIsInstance(amp_flow, flow.Flow)
 
         self.assertIn(constants.FLAVOR, amp_flow.requires)
+        self.assertIn(constants.AVAILABILITY_ZONE, amp_flow.requires)
         self.assertIn(constants.BUILD_TYPE_PRIORITY, amp_flow.requires)
         self.assertIn(constants.LOADBALANCER_ID, amp_flow.requires)
         self.assertIn(constants.SERVER_GROUP_ID, amp_flow.requires)
@@ -230,19 +250,19 @@ class TestAmphoraFlows(base.TestCase):
         self.assertIn(constants.SERVER_PEM, amp_flow.provides)
 
         self.assertEqual(5, len(amp_flow.provides))
-        self.assertEqual(4, len(amp_flow.requires))
+        self.assertEqual(5, len(amp_flow.requires))
         self.conf.config(group="nova", enable_anti_affinity=False)
 
     def test_get_delete_amphora_flow(self, mock_get_net_driver):
 
-        amp_flow = self.AmpFlow.get_delete_amphora_flow()
+        amp_flow = self.AmpFlow.get_delete_amphora_flow(self.amp4.to_dict())
 
         self.assertIsInstance(amp_flow, flow.Flow)
 
-        self.assertIn(constants.AMPHORA, amp_flow.requires)
+        # This flow injects the required data at flow compile time.
 
         self.assertEqual(0, len(amp_flow.provides))
-        self.assertEqual(1, len(amp_flow.requires))
+        self.assertEqual(0, len(amp_flow.requires))
 
     def test_allocate_amp_to_lb_decider(self, mock_get_net_driver):
         history = mock.MagicMock()
@@ -255,105 +275,112 @@ class TestAmphoraFlows(base.TestCase):
 
     def test_create_new_amp_for_lb_decider(self, mock_get_net_driver):
         history = mock.MagicMock()
-        values = mock.MagicMock(side_effect=[[None], ['TEST']])
+        values = mock.MagicMock(side_effect=[[], [None], ['TEST']])
         history.values = values
         result = self.AmpFlow._create_new_amp_for_lb_decider(history)
         self.assertTrue(result)
         result = self.AmpFlow._create_new_amp_for_lb_decider(history)
+        self.assertTrue(result)
+        result = self.AmpFlow._create_new_amp_for_lb_decider(history)
         self.assertFalse(result)
 
-    def test_get_failover_flow_allocated(self, mock_get_net_driver):
+    def test_get_failover_flow_act_stdby(self, mock_get_net_driver):
+        failed_amphora = data_models.Amphora(
+            id=uuidutils.generate_uuid(), role=constants.ROLE_MASTER,
+            load_balancer_id=uuidutils.generate_uuid()).to_dict()
 
-        amp_flow = self.AmpFlow.get_failover_flow(
-            load_balancer=self.lb)
+        amp_flow = self.AmpFlow.get_failover_amphora_flow(
+            failed_amphora, 2)
 
         self.assertIsInstance(amp_flow, flow.Flow)
 
-        self.assertIn(constants.FAILED_AMPHORA, amp_flow.requires)
+        self.assertIn(constants.AVAILABILITY_ZONE, amp_flow.requires)
+        self.assertIn(constants.BUILD_TYPE_PRIORITY, amp_flow.requires)
+        self.assertIn(constants.FLAVOR, amp_flow.requires)
+        self.assertIn(constants.LOADBALANCER, amp_flow.requires)
         self.assertIn(constants.LOADBALANCER_ID, amp_flow.requires)
+        self.assertIn(constants.VIP, amp_flow.requires)
 
-        self.assertIn(constants.AMP_DATA, amp_flow.provides)
+        self.assertIn(constants.ADDED_PORTS, amp_flow.provides)
+        self.assertIn(constants.AMP_VRRP_INT, amp_flow.provides)
         self.assertIn(constants.AMPHORA, amp_flow.provides)
         self.assertIn(constants.AMPHORA_ID, amp_flow.provides)
+        self.assertIn(constants.AMPHORAE, amp_flow.provides)
         self.assertIn(constants.AMPHORAE_NETWORK_CONFIG, amp_flow.provides)
+        self.assertIn(constants.BASE_PORT, amp_flow.provides)
         self.assertIn(constants.COMPUTE_ID, amp_flow.provides)
         self.assertIn(constants.COMPUTE_OBJ, amp_flow.provides)
-        self.assertIn(constants.LISTENERS, amp_flow.provides)
+        self.assertIn(constants.DELTA, amp_flow.provides)
         self.assertIn(constants.LOADBALANCER, amp_flow.provides)
+        self.assertIn(constants.SERVER_PEM, amp_flow.provides)
+        self.assertIn(constants.VIP_SG_ID, amp_flow.provides)
 
-        self.assertEqual(4, len(amp_flow.requires))
-        self.assertEqual(12, len(amp_flow.provides))
+        self.assertEqual(7, len(amp_flow.requires))
+        self.assertEqual(13, len(amp_flow.provides))
 
-        amp_flow = self.AmpFlow.get_failover_flow(
-            role=constants.ROLE_MASTER, load_balancer=self.lb)
+    def test_get_failover_flow_standalone(self, mock_get_net_driver):
+        failed_amphora = data_models.Amphora(
+            id=uuidutils.generate_uuid(), role=constants.ROLE_STANDALONE,
+            load_balancer_id=uuidutils.generate_uuid(),
+            vrrp_ip='2001:3b8::32').to_dict()
+
+        amp_flow = self.AmpFlow.get_failover_amphora_flow(
+            failed_amphora, 1)
 
         self.assertIsInstance(amp_flow, flow.Flow)
 
-        self.assertIn(constants.FAILED_AMPHORA, amp_flow.requires)
+        self.assertIn(constants.AVAILABILITY_ZONE, amp_flow.requires)
+        self.assertIn(constants.BUILD_TYPE_PRIORITY, amp_flow.requires)
+        self.assertIn(constants.FLAVOR, amp_flow.requires)
+        self.assertIn(constants.LOADBALANCER, amp_flow.requires)
         self.assertIn(constants.LOADBALANCER_ID, amp_flow.requires)
+        self.assertIn(constants.VIP, amp_flow.requires)
 
-        self.assertIn(constants.AMP_DATA, amp_flow.provides)
+        self.assertIn(constants.ADDED_PORTS, amp_flow.provides)
         self.assertIn(constants.AMPHORA, amp_flow.provides)
         self.assertIn(constants.AMPHORA_ID, amp_flow.provides)
+        self.assertIn(constants.AMPHORAE, amp_flow.provides)
         self.assertIn(constants.AMPHORAE_NETWORK_CONFIG, amp_flow.provides)
+        self.assertIn(constants.BASE_PORT, amp_flow.provides)
         self.assertIn(constants.COMPUTE_ID, amp_flow.provides)
         self.assertIn(constants.COMPUTE_OBJ, amp_flow.provides)
-        self.assertIn(constants.LISTENERS, amp_flow.provides)
+        self.assertIn(constants.DELTA, amp_flow.provides)
         self.assertIn(constants.LOADBALANCER, amp_flow.provides)
+        self.assertIn(constants.SERVER_PEM, amp_flow.provides)
+        self.assertIn(constants.VIP_SG_ID, amp_flow.provides)
 
-        self.assertEqual(4, len(amp_flow.requires))
+        self.assertEqual(7, len(amp_flow.requires))
         self.assertEqual(12, len(amp_flow.provides))
 
-        amp_flow = self.AmpFlow.get_failover_flow(
-            role=constants.ROLE_BACKUP, load_balancer=self.lb)
+    def test_get_failover_flow_bogus_role(self, mock_get_net_driver):
+        failed_amphora = data_models.Amphora(id=uuidutils.generate_uuid(),
+                                             role='bogus').to_dict()
+
+        amp_flow = self.AmpFlow.get_failover_amphora_flow(
+            failed_amphora, 1)
 
         self.assertIsInstance(amp_flow, flow.Flow)
 
-        self.assertIn(constants.FAILED_AMPHORA, amp_flow.requires)
         self.assertIn(constants.LOADBALANCER_ID, amp_flow.requires)
 
-        self.assertIn(constants.AMP_DATA, amp_flow.provides)
-        self.assertIn(constants.AMPHORA, amp_flow.provides)
-        self.assertIn(constants.AMPHORA_ID, amp_flow.provides)
-        self.assertIn(constants.AMPHORAE_NETWORK_CONFIG, amp_flow.provides)
-        self.assertIn(constants.COMPUTE_ID, amp_flow.provides)
-        self.assertIn(constants.COMPUTE_OBJ, amp_flow.provides)
-        self.assertIn(constants.LISTENERS, amp_flow.provides)
-        self.assertIn(constants.LOADBALANCER, amp_flow.provides)
+        self.assertIn(constants.VIP_SG_ID, amp_flow.provides)
 
-        self.assertEqual(4, len(amp_flow.requires))
-        self.assertEqual(12, len(amp_flow.provides))
-
-        amp_flow = self.AmpFlow.get_failover_flow(
-            role='BOGUSROLE', load_balancer=self.lb)
-
-        self.assertIsInstance(amp_flow, flow.Flow)
-
-        self.assertIn(constants.FAILED_AMPHORA, amp_flow.requires)
-        self.assertIn(constants.LOADBALANCER_ID, amp_flow.requires)
-
-        self.assertIn(constants.AMP_DATA, amp_flow.provides)
-        self.assertIn(constants.AMPHORA, amp_flow.provides)
-        self.assertIn(constants.AMPHORA_ID, amp_flow.provides)
-        self.assertIn(constants.AMPHORAE_NETWORK_CONFIG, amp_flow.provides)
-        self.assertIn(constants.COMPUTE_ID, amp_flow.provides)
-        self.assertIn(constants.COMPUTE_OBJ, amp_flow.provides)
-        self.assertIn(constants.LISTENERS, amp_flow.provides)
-        self.assertIn(constants.LOADBALANCER, amp_flow.provides)
-
-        self.assertEqual(4, len(amp_flow.requires))
-        self.assertEqual(12, len(amp_flow.provides))
+        self.assertEqual(1, len(amp_flow.requires))
+        self.assertEqual(1, len(amp_flow.provides))
 
     def test_get_failover_flow_spare(self, mock_get_net_driver):
 
-        amp_flow = self.AmpFlow.get_failover_flow()
+        amp_flow = self.AmpFlow.get_failover_amphora_flow(
+            self.amp4.to_dict(), 0)
 
         self.assertIsInstance(amp_flow, flow.Flow)
 
-        self.assertIn(constants.FAILED_AMPHORA, amp_flow.requires)
+        self.assertIn(constants.LOADBALANCER_ID, amp_flow.requires)
+
+        self.assertIn(constants.VIP_SG_ID, amp_flow.provides)
 
         self.assertEqual(1, len(amp_flow.requires))
-        self.assertEqual(0, len(amp_flow.provides))
+        self.assertEqual(1, len(amp_flow.provides))
 
     def test_cert_rotate_amphora_flow(self, mock_get_net_driver):
         self.AmpFlow = amphora_flows.AmphoraFlows()
@@ -372,12 +399,30 @@ class TestAmphoraFlows(base.TestCase):
 
         self.assertIsInstance(vrrp_subflow, flow.Flow)
 
-        self.assertIn(constants.LOADBALANCER, vrrp_subflow.provides)
+        self.assertIn(constants.AMPHORAE_NETWORK_CONFIG, vrrp_subflow.provides)
+        self.assertIn(constants.AMP_VRRP_INT, vrrp_subflow.provides)
 
-        self.assertIn(constants.LOADBALANCER, vrrp_subflow.requires)
+        self.assertIn(constants.LOADBALANCER_ID, vrrp_subflow.requires)
+        self.assertIn(constants.AMPHORAE, vrrp_subflow.requires)
 
         self.assertEqual(2, len(vrrp_subflow.provides))
-        self.assertEqual(1, len(vrrp_subflow.requires))
+        self.assertEqual(2, len(vrrp_subflow.requires))
+
+    def test_get_vrrp_subflow_dont_create_vrrp_group(
+            self, mock_get_net_driver):
+        vrrp_subflow = self.AmpFlow.get_vrrp_subflow('123',
+                                                     create_vrrp_group=False)
+
+        self.assertIsInstance(vrrp_subflow, flow.Flow)
+
+        self.assertIn(constants.AMPHORAE_NETWORK_CONFIG, vrrp_subflow.provides)
+        self.assertIn(constants.AMP_VRRP_INT, vrrp_subflow.provides)
+
+        self.assertIn(constants.LOADBALANCER_ID, vrrp_subflow.requires)
+        self.assertIn(constants.AMPHORAE, vrrp_subflow.requires)
+
+        self.assertEqual(2, len(vrrp_subflow.provides))
+        self.assertEqual(2, len(vrrp_subflow.requires))
 
     def test_get_post_map_lb_subflow(self, mock_get_net_driver):
 
@@ -389,10 +434,9 @@ class TestAmphoraFlows(base.TestCase):
         self.assertIsInstance(amp_flow, flow.Flow)
 
         self.assertIn(constants.FLAVOR, amp_flow.requires)
-        self.assertIn(constants.AMPHORA_ID, amp_flow.requires)
-        self.assertIn(constants.AMPHORA, amp_flow.provides)
+        self.assertIn(constants.AMPHORA, amp_flow.requires)
 
-        self.assertEqual(1, len(amp_flow.provides))
+        self.assertEqual(0, len(amp_flow.provides))
         self.assertEqual(2, len(amp_flow.requires))
 
         amp_flow = self.AmpFlow._get_post_map_lb_subflow(
@@ -401,10 +445,9 @@ class TestAmphoraFlows(base.TestCase):
         self.assertIsInstance(amp_flow, flow.Flow)
 
         self.assertIn(constants.FLAVOR, amp_flow.requires)
-        self.assertIn(constants.AMPHORA_ID, amp_flow.requires)
-        self.assertIn(constants.AMPHORA, amp_flow.provides)
+        self.assertIn(constants.AMPHORA, amp_flow.requires)
 
-        self.assertEqual(1, len(amp_flow.provides))
+        self.assertEqual(0, len(amp_flow.provides))
         self.assertEqual(2, len(amp_flow.requires))
 
         amp_flow = self.AmpFlow._get_post_map_lb_subflow(
@@ -413,10 +456,9 @@ class TestAmphoraFlows(base.TestCase):
         self.assertIsInstance(amp_flow, flow.Flow)
 
         self.assertIn(constants.FLAVOR, amp_flow.requires)
-        self.assertIn(constants.AMPHORA_ID, amp_flow.requires)
-        self.assertIn(constants.AMPHORA, amp_flow.provides)
+        self.assertIn(constants.AMPHORA, amp_flow.requires)
 
-        self.assertEqual(1, len(amp_flow.provides))
+        self.assertEqual(0, len(amp_flow.provides))
         self.assertEqual(2, len(amp_flow.requires))
 
         amp_flow = self.AmpFlow._get_post_map_lb_subflow(
@@ -425,10 +467,9 @@ class TestAmphoraFlows(base.TestCase):
         self.assertIsInstance(amp_flow, flow.Flow)
 
         self.assertIn(constants.FLAVOR, amp_flow.requires)
-        self.assertIn(constants.AMPHORA_ID, amp_flow.requires)
-        self.assertIn(constants.AMPHORA, amp_flow.provides)
+        self.assertIn(constants.AMPHORA, amp_flow.requires)
 
-        self.assertEqual(1, len(amp_flow.provides))
+        self.assertEqual(0, len(amp_flow.provides))
         self.assertEqual(2, len(amp_flow.requires))
 
     def test_update_amphora_config_flow(self, mock_get_net_driver):
@@ -442,3 +483,30 @@ class TestAmphoraFlows(base.TestCase):
 
         self.assertEqual(2, len(amp_flow.requires))
         self.assertEqual(0, len(amp_flow.provides))
+
+    def test__retry_flow(self, mock_get_net_driver):
+        amp_flow = self.AmpFlow._retry_flow('test_flow')
+
+        self.assertIsInstance(amp_flow, flow.Flow)
+
+        self.assertIn(constants.AMPHORA, amp_flow.requires)
+
+        self.assertEqual(1, len(amp_flow.requires))
+        self.assertEqual(0, len(amp_flow.provides))
+
+    def test__finalize_flow(self, mock_get_net_driver):
+        for role in [constants.ROLE_STANDALONE,
+                     constants.ROLE_BACKUP,
+                     constants.ROLE_MASTER]:
+
+            amp_flow = self.AmpFlow._finalize_flow('test',
+                                                   role)
+
+            self.assertIsInstance(amp_flow, flow.Flow)
+
+            self.assertIn(constants.AMPHORA, amp_flow.requires)
+            self.assertIn(constants.LOADBALANCER_ID, amp_flow.requires)
+            self.assertIn(constants.AMPHORA, amp_flow.provides)
+
+            self.assertEqual(2, len(amp_flow.requires))
+            self.assertEqual(1, len(amp_flow.provides))
