@@ -11,8 +11,8 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
+from unittest import mock
 
-import mock
 from neutronclient.common import exceptions as neutron_client_exceptions
 from oslo_config import cfg
 from oslo_config import fixture as oslo_fixture
